@@ -1,27 +1,16 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionrewriteheadertest.h"
-#include <QTest>
 #include "../filteractions/filteractionrewriteheader.h"
 #include <KLineEdit>
-#include <QLabel>
-#include <QWidget>
 #include <QComboBox>
+#include <QLabel>
+#include <QTest>
+#include <QWidget>
 
 FilterActionRewriteHeaderTest::FilterActionRewriteHeaderTest(QObject *parent)
     : QObject(parent)
@@ -40,17 +29,17 @@ void FilterActionRewriteHeaderTest::shouldHaveDefaultValue()
     QVERIFY(combo);
     QVERIFY(combo->count() > 0);
 
-    QLabel *label = w->findChild<QLabel *>(QStringLiteral("label_replace"));
+    auto *label = w->findChild<QLabel *>(QStringLiteral("label_replace"));
     QVERIFY(label);
 
-    KLineEdit *regExpLineEdit = w->findChild<KLineEdit *>(QStringLiteral("search"));
+    auto *regExpLineEdit = w->findChild<KLineEdit *>(QStringLiteral("search"));
     QVERIFY(regExpLineEdit);
     QVERIFY(regExpLineEdit->text().isEmpty());
 
     label = w->findChild<QLabel *>(QStringLiteral("label_with"));
     QVERIFY(label);
 
-    KLineEdit *lineEdit = w->findChild<KLineEdit *>(QStringLiteral("replace"));
+    auto *lineEdit = w->findChild<KLineEdit *>(QStringLiteral("replace"));
     QVERIFY(lineEdit);
     QVERIFY(lineEdit->text().isEmpty());
 }
@@ -97,22 +86,26 @@ void FilterActionRewriteHeaderTest::shouldNotExecuteActionWhenValueIsEmpty()
 
 void FilterActionRewriteHeaderTest::shouldRewriteHeader()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "testheader: foo\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "\n"
-                            "test";
-    const QByteArray output = "From: foo@kde.org\n"
-                              "To: foo@kde.org\n"
-                              "Subject: test\n"
-                              "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                              "MIME-Version: 1.0\n"
-                              "testheader: bla\n"
-                              "\n"
-                              "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "testheader: foo\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
+    const QByteArray output =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "testheader: bla\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRewriteHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
@@ -130,13 +123,15 @@ void FilterActionRewriteHeaderTest::shouldRewriteHeader()
 
 void FilterActionRewriteHeaderTest::shouldNotRewriteHeaderWhenHeaderNotFound()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "\n"
-                            "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRewriteHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
@@ -154,14 +149,16 @@ void FilterActionRewriteHeaderTest::shouldNotRewriteHeaderWhenHeaderNotFound()
 
 void FilterActionRewriteHeaderTest::shouldNotRewriteHeaderWhenRegexpNotFound()
 {
-    const QByteArray data = "From: foo@kde.org\n"
-                            "To: foo@kde.org\n"
-                            "Subject: test\n"
-                            "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
-                            "MIME-Version: 1.0\n"
-                            "testheader: bla\n"
-                            "\n"
-                            "test";
+    const QByteArray data =
+        "From: foo@kde.org\n"
+        "To: foo@kde.org\n"
+        "Subject: test\n"
+        "Date: Wed, 01 Apr 2015 09:33:01 +0200\n"
+        "MIME-Version: 1.0\n"
+        "Content-Type: text/plain; charset=\"us-ascii\"\n"
+        "testheader: bla\n"
+        "\n"
+        "test";
 
     MailCommon::FilterActionRewriteHeader filter(this);
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
