@@ -1,7 +1,7 @@
 #include "filteractionsettransporttest.h"
 #include "../filteractions/filteractionsettransport.h"
-#include <QTest>
 #include <MailTransport/TransportComboBox>
+#include <QTest>
 
 FilterActionSetTransportTest::FilterActionSetTransportTest(QObject *parent)
     : QObject(parent)
@@ -24,7 +24,7 @@ void FilterActionSetTransportTest::shouldHaveDefaultValue()
     QWidget *w = filter.createParamWidget(nullptr);
     QCOMPARE(w->objectName(), QStringLiteral("transportcombobox"));
 
-    MailTransport::TransportComboBox *transportCombobox = dynamic_cast<MailTransport::TransportComboBox *>(w);
+    auto *transportCombobox = dynamic_cast<MailTransport::TransportComboBox *>(w);
     QVERIFY(transportCombobox);
 }
 
