@@ -5,12 +5,12 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONDELETE_H
-#define MAILCOMMON_FILTERACTIONDELETE_H
+#pragma once
 
 #include "filteractionwithnone.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 //=============================================================================
 // FilterActionDelete - Delete action
 //=============================================================================
@@ -27,4 +27,3 @@ public:
 };
 }
 
-#endif
