@@ -5,12 +5,12 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONSENDFAKEDISPOSITION_H
-#define MAILCOMMON_FILTERACTIONSENDFAKEDISPOSITION_H
+#pragma once
 
 #include "filteractionwithstringlist.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 //=============================================================================
 // FilterActionSendFakeDisposition - send fake MDN
 // Sends a fake MDN or forces an ignore.
@@ -34,4 +34,3 @@ public:
 };
 }
 
-#endif
