@@ -5,12 +5,12 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONSETIDENTITY_H
-#define MAILCOMMON_FILTERACTIONSETIDENTITY_H
+#pragma once
 
 #include "filteractionwithuoid.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 //=============================================================================
 // FilterActionSetIdentity - set identity to
 // Specify Identity to be used when replying to a message
@@ -32,4 +32,3 @@ public:
 };
 }
 
-#endif
