@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filteractionunsetstatus.h"
@@ -59,8 +47,8 @@ FilterAction::ReturnCode FilterActionUnsetStatus::process(ItemContext &context,
     Akonadi::MessageStatus status;
     status.setStatusFromFlags(context.item().flags());
 
-    Akonadi::MessageStatus newStatus = FilterActionStatus::stati[ index - 1 ];
-    //Laurent unread status doesn't exist. And crash if we use "const Akonadi::Item::Flag flag = *(flags.begin());" etc. => if we unset "unread" we set read
+    Akonadi::MessageStatus newStatus = FilterActionStatus::stati[index - 1];
+    // Laurent unread status doesn't exist. And crash if we use "const Akonadi::Item::Flag flag = *(flags.begin());" etc. => if we unset "unread" we set read
     if (newStatus == Akonadi::MessageStatus::statusUnread()) {
         Akonadi::MessageStatus oldStatus = status;
         newStatus.setRead(true);
