@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -21,6 +9,8 @@
 #include "mailcommon_debug.h"
 #include <KProcess>
 #include <KShell>
+
+#include <QRegularExpression>
 #include <QTemporaryFile>
 
 using namespace MailCommon;
@@ -71,16 +61,14 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
 {
     QString result = mParameter;
     QList<int> argList;
-    QRegExp r(QStringLiteral("%[0-9-]+"));
+    const QRegularExpression re(QStringLiteral("%([0-9-]+)"));
 
     // search for '%n'
-    int start = -1;
-    while ((start = r.indexIn(result, start + 1)) > 0) {
-        const int len = r.matchedLength();
-
+    QRegularExpressionMatchIterator iter = re.globalMatch(result);
+    while (iter.hasNext()) {
         // and save the encountered 'n' in a list.
         bool ok = false;
-        const int n = result.midRef(start + 1, len - 1).toInt(&ok);
+        const int n = iter.next().captured(1).toInt(&ok);
         if (ok) {
             argList.append(n);
         }
@@ -96,7 +84,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     for (QList<int>::ConstIterator it = argList.constBegin(); it != end; ++it) {
         // setup temp files with check for duplicate %n's
         if ((*it) != lastSeen) {
-            QTemporaryFile *tempFile = new QTemporaryFile();
+            auto tempFile = new QTemporaryFile();
             if (!tempFile->open()) {
                 delete tempFile;
                 qCDebug(MAILCOMMON_LOG) << "FilterActionWithCommand: Could not create temp file!";
@@ -141,7 +129,8 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     return result;
 }
 
-namespace {
+namespace
+{
 /**
  * Substitutes placeholders in the command line with the
  * content of the corresponding header in the message.
@@ -151,16 +140,18 @@ void substituteMessageHeaders(const KMime::Message::Ptr &aMsg, QString &result)
 {
     // Replace the %{foo} with the content of the foo header field.
     // If the header doesn't exist, remove the placeholder.
-    QRegExp header_rx(QStringLiteral("%\\{([a-z0-9-]+)\\}"), Qt::CaseInsensitive);
-    int idx = 0;
-    while ((idx = header_rx.indexIn(result, idx)) != -1) {
-        const KMime::Headers::Base *header = aMsg->headerByType(header_rx.cap(1).toLatin1().constData());
+    const QRegularExpression header_rx(QStringLiteral("%\\{([a-z0-9-]+)\\}"), QRegularExpression::CaseInsensitiveOption);
+    int offset = 0;
+    QRegularExpressionMatch rmatch;
+    while (result.indexOf(header_rx, offset, &rmatch) != -1) {
+        const KMime::Headers::Base *header = aMsg->headerByType(rmatch.captured(1).toLatin1().constData());
         QString replacement;
         if (header) {
             replacement = KShell::quoteArg(QString::fromLatin1(header->as7BitString()));
         }
-        result.replace(idx, header_rx.matchedLength(), replacement);
-        idx += replacement.length();
+        const int start = rmatch.capturedStart(0);
+        result.replace(start, rmatch.capturedLength(0), replacement);
+        offset = start + replacement.size();
     }
 }
 
@@ -178,7 +169,7 @@ void substituteCommandLineArgsForItem(const Akonadi::Item &item, QString &comman
 
 FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &context, bool withOutput) const
 {
-    const KMime::Message::Ptr aMsg = context.item().payload<KMime::Message::Ptr>();
+    const auto aMsg = context.item().payload<KMime::Message::Ptr>();
     Q_ASSERT(aMsg);
 
     if (mParameter.isEmpty()) {
@@ -187,7 +178,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
 
     // KProcess doesn't support a QProcess::launch() equivalent, so
     // we must use a temp file :-(
-    QTemporaryFile *inFile = new QTemporaryFile;
+    auto inFile = new QTemporaryFile;
     if (!inFile->open()) {
         delete inFile;
         return ErrorButGoOn;
@@ -262,7 +253,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
             }
             if (uid != newUid) {
                 aMsg->setFrozen(false);
-                KMime::Headers::Generic *header = new KMime::Headers::Generic("X-UID");
+                auto header = new KMime::Headers::Generic("X-UID");
                 header->fromUnicodeString(uid, "utf-8");
                 aMsg->setHeader(header);
                 aMsg->assemble();
