@@ -1,28 +1,16 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONWITHNONE_H
-#define MAILCOMMON_FILTERACTIONWITHNONE_H
+#pragma once
 
 #include "filteraction.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  *  @short Abstract base class for filter actions with no parameter.
  *
@@ -64,4 +52,3 @@ public:
 };
 }
 
-#endif
