@@ -1,28 +1,16 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONWITHUOID_H
-#define MAILCOMMON_FILTERACTIONWITHUOID_H
+#pragma once
 
 #include "filteraction.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @short Abstract base class for filter actions with a free-form string as parameter.
  *
@@ -50,7 +38,7 @@ public:
     /**
      * @copydoc FilterAction::isEmpty
      */
-    bool isEmpty() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
 
     /**
      * @copydoc FilterAction::argsFromString
@@ -60,16 +48,15 @@ public:
     /**
      * @copydoc FilterAction::argsAsString
      */
-    QString argsAsString() const override;
+    Q_REQUIRED_RESULT QString argsAsString() const override;
 
     /**
      * @copydoc FilterAction::displayString
      */
-    QString displayString() const override;
+    Q_REQUIRED_RESULT QString displayString() const override;
 
 protected:
     uint mParameter;
 };
 }
 
-#endif
