@@ -1,24 +1,12 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterconverttosieve.h"
-#include "filterconverttosieveresultdialog.h"
 #include "filter/mailfilter.h"
+#include "filterconverttosieveresultdialog.h"
 
 #include <QPointer>
 
@@ -39,12 +27,12 @@ void FilterConvertToSieve::convert()
     if (!mListFilters.isEmpty()) {
         QStringList requiresModule;
         QString code;
-        for (MailFilter *filter : qAsConst(mListFilters)) {
+        for (MailFilter *filter : std::as_const(mListFilters)) {
             filter->generateSieveScript(requiresModule, code);
             code += QLatin1Char('\n');
         }
         QString requireStr;
-        for (const QString &require : qAsConst(requiresModule)) {
+        for (const QString &require : std::as_const(requiresModule)) {
             requireStr += QStringLiteral("require \"%1\";").arg(require);
             requireStr += QLatin1Char('\n');
         }
