@@ -6,8 +6,8 @@
 #include "filterimportbalsatest.h"
 #include "filter/mailfilter.h"
 #include "filtertestkernel.h"
-#include <AkonadiCore/qtest_akonadi.h>
 #include <MailCommon/MailKernel>
+#include <akonadi/qtest_akonadi.h>
 
 void FilterImportBalsatest::initTestCase()
 {
