@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimporterclawsmail.h"
@@ -21,8 +9,8 @@
 #include "filter/mailfilter.h"
 #include "mailcommon_debug.h"
 
-#include <QFile>
 #include <QDir>
+#include <QFile>
 
 using namespace MailCommon;
 
@@ -57,9 +45,9 @@ void FilterImporterClawsMails::readStream(QTextStream &stream)
         qCDebug(MAILCOMMON_LOG) << " line :" << line << " filter " << filter;
 
         if (line.isEmpty()) {
-            //Nothing
+            // Nothing
         } else if (line.startsWith(QLatin1Char('[')) && line.endsWith(QLatin1Char(']'))) {
-            //TODO
+            // TODO
         } else {
             appendFilter(filter);
             filter = parseLine(line);
@@ -75,15 +63,15 @@ QString FilterImporterClawsMails::defaultFiltersSettingsPath()
 
 MailFilter *FilterImporterClawsMails::parseLine(const QString &line)
 {
-    MailFilter *filter = new MailFilter();
+    auto filter = new MailFilter();
     QString tmp = line;
-    //Enabled ?
+    // Enabled ?
     if (tmp.startsWith(QLatin1String("enabled"))) {
         filter->setEnabled(true);
         tmp.remove(QStringLiteral("enabled "));
     }
 
-    //Filter name
+    // Filter name
     if (tmp.startsWith(QLatin1String("rulename"))) {
         tmp.remove(QStringLiteral("rulename "));
         int pos;
@@ -91,33 +79,33 @@ MailFilter *FilterImporterClawsMails::parseLine(const QString &line)
         filter->pattern()->setName(name);
         filter->setToolbarName(name);
 
-        tmp = tmp.mid(pos + 2); //remove "\" "
+        tmp = tmp.mid(pos + 2); // remove "\" "
         qCDebug(MAILCOMMON_LOG) << " new tmp" << tmp;
     }
 
     tmp = extractConditions(tmp, filter);
 
     tmp = extractActions(tmp, filter);
-    //TODO
+    // TODO
     return filter;
 }
 
 QString FilterImporterClawsMails::extractActions(const QString &line, MailFilter *filter)
 {
-    Q_UNUSED(filter);
+    Q_UNUSED(filter)
     return line;
 }
 
 QString FilterImporterClawsMails::extractConditions(const QString &line, MailFilter *filter)
 {
     QByteArray fieldName;
-    //Action
+    // Action
     if (line.startsWith(QLatin1String("subject"))) {
         fieldName = "subject";
     } else if (line.startsWith(QLatin1String("age_lower"))) {
     }
     filter->pattern()->setOp(SearchPattern::OpAnd);
-    //TODO
+    // TODO
     return QString();
 }
 
