@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimportergmail.h"
+#include "filter/mailfilter.h"
 #include "mailcommon_debug.h"
-#include <QFile>
 #include <QDir>
 #include <QDomDocument>
-#include "filter/mailfilter.h"
+#include <QFile>
 
 using namespace MailCommon;
 
@@ -64,16 +52,14 @@ QString FilterImporterGmail::createUniqFilterName()
 
 void FilterImporterGmail::parseFilters(const QDomElement &e)
 {
-    MailCommon::MailFilter *filter = new MailCommon::MailFilter();
+    auto filter = new MailCommon::MailFilter();
     filter->setAutoNaming(true);
     const QString uniqName = createUniqFilterName();
     filter->pattern()->setName(uniqName);
     filter->setToolbarName(uniqName);
     filter->setEnabled(true);
     QByteArray fieldName;
-    for (QDomElement ruleFilter = e.firstChildElement();
-         !ruleFilter.isNull();
-         ruleFilter = ruleFilter.nextSiblingElement()) {
+    for (QDomElement ruleFilter = e.firstChildElement(); !ruleFilter.isNull(); ruleFilter = ruleFilter.nextSiblingElement()) {
         const QString tagName = ruleFilter.tagName();
         if (tagName == QLatin1String("category")) {
             if (ruleFilter.hasAttribute(QStringLiteral("term"))) {
@@ -97,7 +83,7 @@ void FilterImporterGmail::parseFilters(const QDomElement &e)
                 } else if (criteriaProperty == QLatin1String("hasAttachment")) {
                     fieldName = "<size>";
                 }
-                //Action
+                // Action
                 else if (criteriaProperty == QLatin1String("shouldArchive")) {
                 } else if (criteriaProperty == QLatin1String("shouldMarkAsRead")) {
                 } else if (criteriaProperty == QLatin1String("shouldStar")) {
