@@ -1,30 +1,18 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "invalidfilterdialog.h"
-#include "invalidfilterwidget.h"
 #include "invalidfilterinfowidget.h"
+#include "invalidfilterwidget.h"
 #include <KConfigGroup>
-#include <KSharedConfig>
-#include <QVBoxLayout>
 #include <KLocalizedString>
+#include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace MailCommon;
 
@@ -33,9 +21,9 @@ InvalidFilterDialog::InvalidFilterDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Invalid Filters"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
@@ -44,9 +32,9 @@ InvalidFilterDialog::InvalidFilterDialog(QWidget *parent)
     setModal(true);
     okButton->setText(i18n("Discard"));
 
-    QWidget *w = new QWidget(this);
-    QVBoxLayout *vbox = new QVBoxLayout;
-    vbox->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(this);
+    auto vbox = new QVBoxLayout;
+    vbox->setContentsMargins({});
     w->setLayout(vbox);
     mInvalidFilterWidget = new InvalidFilterWidget(this);
     mInvalidFilterWidget->setObjectName(QStringLiteral("invalid_filter_widget"));
@@ -74,13 +62,13 @@ void InvalidFilterDialog::setInvalidFilters(const QVector<InvalidFilterInfo> &ls
 
 void InvalidFilterDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "InvalidFilterDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "InvalidFilterDialog");
     group.writeEntry("Size", size());
 }
 
 void InvalidFilterDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "InvalidFilterDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "InvalidFilterDialog");
     const QSize sizeDialog = group.readEntry("Size", QSize(400, 500));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
