@@ -1,24 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INVALIDFILTERLISTMODEL_H
-#define INVALIDFILTERLISTMODEL_H
+#pragma once
 
+#include "invalidfilterinfo.h"
 #include <QAbstractListModel>
 #include <QVector>
-#include "invalidfilterinfo.h"
-namespace MailCommon {
+namespace MailCommon
+{
 class InvalidFilterListModel : public QAbstractListModel
 {
     Q_OBJECT
 
 public:
-    enum Role {
-        InformationRole = Qt::UserRole + 1
-    };
+    enum Role { InformationRole = Qt::UserRole + 1 };
 
     explicit InvalidFilterListModel(QObject *parent = nullptr);
     ~InvalidFilterListModel() override;
@@ -33,4 +31,3 @@ private:
 };
 }
 
-#endif // INVALIDFILTERLISTMODEL_H
