@@ -1,17 +1,17 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INVALIDFILTERWIDGET_H
-#define INVALIDFILTERWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "invalidfilterinfo.h"
 #include "mailcommon_export.h"
+#include <QWidget>
 
-namespace MailCommon {
+namespace MailCommon
+{
 class InvalidFilterListView;
 /**
  * @brief The InvalidFilterWidget class
@@ -22,15 +22,15 @@ class MAILCOMMON_EXPORT InvalidFilterWidget : public QWidget
     Q_OBJECT
 public:
     explicit InvalidFilterWidget(QWidget *parent = nullptr);
-    ~InvalidFilterWidget();
+    ~InvalidFilterWidget() override;
 
     void setInvalidFilters(const QVector<MailCommon::InvalidFilterInfo> &lst);
 Q_SIGNALS:
     void showDetails(const QString &);
     void hideInformationWidget();
+
 private:
-    InvalidFilterListView *mInvalidFilterListWidget = nullptr;
+    InvalidFilterListView *const mInvalidFilterListWidget;
 };
 }
 
-#endif // INVALIDFILTERWIDGET_H
