@@ -1,75 +1,63 @@
 /*
   Filter Dialog
-  Author: Marc Mutz <mutz@kde.org>
+
+  SPDX-FileCopyrightText: Marc Mutz <mutz@kde.org>
+  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+
   based upon work by Stefan Taferner <taferner@kde.org>
 
-  Copyright (c) 2011-2017 Laurent Montel <montel@kde.org>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kmfilterdialog.h"
-#include "mailcommon_debug.h"
 #include "kmfilterlistbox.h"
+#include "mailcommon_debug.h"
 
-#include "filterimporterpathcache.h"
 #include "filteractions/filteractiondict.h"
 #include "filteractions/filteractionwidget.h"
-#include "filterimporterexporter.h"
+#include "filterimporterpathcache.h"
 #include "filterselectiondialog.h"
 #include "kmfilteraccountlist.h"
 using MailCommon::FilterImporterExporter;
+#include "filterconverter/filterconverttosieve.h"
 #include "filtermanager.h"
 #include "folder/folderrequester.h"
 #include "kernel/mailkernel.h"
-#include "util/mailutil.h"
 #include "search/searchpatternedit.h"
-#include "filterconverter/filterconverttosieve.h"
+#include "util/mailutil.h"
 #include <PimCommon/PimUtil>
 
-#include <ItemFetchJob>
+#include <Akonadi/ItemFetchJob>
 
 #include <KConfigGroup>
 
+#include <KIconButton>
 #include <KIconLoader>
 #include <KJob>
 #include <KKeySequenceWidget>
 #include <KListWidgetSearchLine>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QIcon>
 #include <QPushButton>
 #include <QTabWidget>
-#include <KWindowSystem>
-#include <KIconButton>
-#include <QIcon>
 
-#include <QApplication>
 #include <QButtonGroup>
 #include <QCheckBox>
+#include <QDialogButtonBox>
+#include <QFormLayout>
 #include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QMenu>
+#include <QPointer>
 #include <QRadioButton>
-#include <QTreeWidget>
-#include <QVBoxLayout>
 #include <QShortcut>
 #include <QSplitter>
-#include <QPointer>
-#include <QKeyEvent>
-#include <QHBoxLayout>
-#include <QDialogButtonBox>
+#include <QTreeWidget>
+#include <QVBoxLayout>
 
 Q_DECLARE_METATYPE(MailCommon::FilterImporterExporter::FilterType)
 using namespace MailCommon;
@@ -82,39 +70,31 @@ using namespace MailCommon;
 
 KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollection, QWidget *parent, bool createDummyFilter)
     : QDialog(parent)
-    , mFilter(nullptr)
-    , mDoNotClose(false)
-    , mIgnoreFilterUpdates(true)
 {
-    setWindowTitle(i18n("Filter Rules"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    setWindowTitle(i18nc("@title:window", "Filter Rules"));
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    QPushButton *user1Button = new QPushButton(this);
+    auto user1Button = new QPushButton(this);
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
-    QPushButton *user2Button = new QPushButton(this);
+    auto user2Button = new QPushButton(this);
     buttonBox->addButton(user2Button, QDialogButtonBox::ActionRole);
-    QPushButton *user3Button = new QPushButton(this);
+    auto user3Button = new QPushButton(this);
     buttonBox->addButton(user3Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KMFilterDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(buttonBox->button(QDialogButtonBox::Help), &QAbstractButton::clicked, this, &KMFilterDialog::slotHelp);
     setModal(false);
     okButton->setFocus();
-    KWindowSystem::setIcons(winId(),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),
-                                                      IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),
-                                                      IconSize(KIconLoader::Small)));
     user1Button->setText(i18n("Import..."));
     user2Button->setText(i18n("Export..."));
     user3Button->setText(i18n("Convert to..."));
-    QMenu *menu = new QMenu();
+    auto menu = new QMenu(this);
 
-    QAction *act = new QAction(i18n("KMail filters"), this);
+    auto act = new QAction(i18n("KMail filters"), this);
     act->setData(QVariant::fromValue(MailCommon::FilterImporterExporter::KMailFilter));
     menu->addAction(act);
 
@@ -154,175 +134,161 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
 
     user1Button->setMenu(menu);
 
-    menu = new QMenu();
+    menu = new QMenu(this);
 
     act = new QAction(i18n("Sieve script"), this);
     connect(act, &QAction::triggered, this, &KMFilterDialog::slotExportAsSieveScript);
     menu->addAction(act);
     user3Button->setMenu(menu);
 
-    connect(user2Button, &QAbstractButton::clicked,
-            this, &KMFilterDialog::slotExportFilters);
+    connect(user2Button, &QAbstractButton::clicked, this, &KMFilterDialog::slotExportFilters);
     mApplyButton = buttonBox->button(QDialogButtonBox::Apply);
     mApplyButton->setEnabled(false);
 
-    QWidget *w = new QWidget(this);
+    auto w = new QWidget(this);
     mainLayout->addWidget(w);
     mainLayout->addWidget(buttonBox);
-    QVBoxLayout *topVLayout = new QVBoxLayout(w);
-    topVLayout->setMargin(0);
-    QHBoxLayout *topLayout = new QHBoxLayout;
+    auto topVLayout = new QVBoxLayout(w);
+    topVLayout->setContentsMargins({});
+    auto topLayout = new QHBoxLayout;
     topVLayout->addLayout(topLayout);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins({});
 
-    QSplitter *splitter = new QSplitter;
+    auto splitter = new QSplitter;
     splitter->setChildrenCollapsible(false);
     topLayout->addWidget(splitter);
 
     mFilterList = new KMFilterListBox(i18n("Available Filters"), this);
     splitter->addWidget(mFilterList);
-    QTabWidget *tabWidget = new QTabWidget(this);
+    auto tabWidget = new QTabWidget(this);
     splitter->addWidget(tabWidget);
 
-    QWidget *page1 = new QWidget(tabWidget);
+    auto page1 = new QWidget(tabWidget);
     tabWidget->addTab(page1, i18nc("General mail filter settings.", "General"));
-    QHBoxLayout *hbl = new QHBoxLayout(page1);
+    auto hbl = new QHBoxLayout(page1);
 
-    QWidget *page2 = new QWidget(tabWidget);
+    auto page2 = new QWidget(tabWidget);
     tabWidget->addTab(page2, i18nc("Advanced mail filter settings.", "Advanced"));
-    QVBoxLayout *vbl2 = new QVBoxLayout(page2);
+    auto vbl2 = new QVBoxLayout(page2);
 
-    QVBoxLayout *vbl = new QVBoxLayout();
+    auto vbl = new QVBoxLayout();
     hbl->addLayout(vbl);
     hbl->setStretchFactor(vbl, 2);
 
-    QGroupBox *patternGroupBox = new QGroupBox(i18n("Filter Criteria"), page1);
-    QHBoxLayout *layout = new QHBoxLayout(patternGroupBox);
-    mPatternEdit
-        = new MailCommon::SearchPatternEdit(
-        patternGroupBox, MailCommon::SearchPatternEdit::MatchAllMessages);
-    layout->addWidget(mPatternEdit);
+    mPatternEdit = new MailCommon::SearchPatternEdit(page1, MailCommon::SearchPatternEdit::MatchAllMessages);
+    vbl->addWidget(mPatternEdit, 0, Qt::AlignTop);
 
-    vbl->addWidget(patternGroupBox, 0, Qt::AlignTop);
+    auto actionLabel = new QLabel(i18n("Filter actions:"), page1);
+    vbl->addWidget(actionLabel);
 
-    QGroupBox *agb = new QGroupBox(i18n("Filter Actions"), page1);
-    QHBoxLayout *layout2 = new QHBoxLayout;
-    mActionLister = new MailCommon::FilterActionWidgetLister(agb);
-    layout2->addWidget(mActionLister);
-    agb->setLayout(layout2);
-    vbl->addWidget(agb, 0, Qt::AlignTop);
+    mActionLister = new MailCommon::FilterActionWidgetLister(page1);
+    vbl->addWidget(mActionLister);
 
-    mAdvOptsGroup = new QGroupBox(i18n("Advanced Options"), page2);
+    mAdvOptsGroup = new QGroupBox(QString(), page2);
+    mAdvOptsGroup->setFlat(true);
+    mAdvOptsGroup->setContentsMargins({});
     {
-        QGridLayout *gl = new QGridLayout();
-        QVBoxLayout *vbl3 = new QVBoxLayout();
-        gl->addLayout(vbl3, 0, 0);
-        vbl3->addStretch(1);
-
+        auto gl = new QGridLayout();
         mApplyOnIn = new QCheckBox(i18n("Apply this filter to incoming messages:"), mAdvOptsGroup);
-        vbl3->addWidget(mApplyOnIn);
+        gl->addWidget(mApplyOnIn, 0, 0);
 
-        QButtonGroup *bg = new QButtonGroup(mAdvOptsGroup);
+        auto radioGroupWidget = new QWidget(page2);
+        radioGroupWidget->setContentsMargins(20, 0, 0, 0);
+        gl->addWidget(radioGroupWidget, 1, 0);
+        auto vbl3 = new QVBoxLayout(radioGroupWidget);
 
-        mApplyOnForAll = new QRadioButton(i18n("from all accounts"), mAdvOptsGroup);
+        auto bg = new QButtonGroup(mAdvOptsGroup);
+
+        mApplyOnForAll = new QRadioButton(i18n("From all accounts"), radioGroupWidget);
         bg->addButton(mApplyOnForAll);
         vbl3->addWidget(mApplyOnForAll);
 
-        mApplyOnForTraditional
-            = new QRadioButton(i18n("from all but online IMAP accounts"), mAdvOptsGroup);
+        mApplyOnForTraditional = new QRadioButton(i18n("From all but online IMAP accounts"), radioGroupWidget);
         bg->addButton(mApplyOnForTraditional);
         vbl3->addWidget(mApplyOnForTraditional);
 
-        mApplyOnForChecked
-            = new QRadioButton(i18n("from checked accounts only"), mAdvOptsGroup);
+        mApplyOnForChecked = new QRadioButton(i18n("From selected accounts only"), radioGroupWidget);
         bg->addButton(mApplyOnForChecked);
         vbl3->addWidget(mApplyOnForChecked);
-        vbl3->addStretch(2);
+        vbl3->addStretch(100);
 
         mAccountList = new KMFilterAccountList(mAdvOptsGroup);
         gl->addWidget(mAccountList, 0, 1, 4, 3);
 
-        mApplyOnOut
-            = new QCheckBox(i18n("Apply this filter to &sent messages"), mAdvOptsGroup);
+        mApplyOnOut = new QCheckBox(i18n("Apply this filter to &sent messages"), mAdvOptsGroup);
         mApplyOnOut->setToolTip(
             i18n("<p>The filter will be triggered <b>after</b> the message is sent "
                  "and it will only affect the local copy of the message.</p>"
                  "<p>If the recipient's copy also needs to be modified, "
                  "please use \"Apply this filter <b>before</b> sending messages\".</p>"));
-        gl->addWidget(mApplyOnOut, 4, 0, 1, 4);
+        gl->addWidget(mApplyOnOut, 5, 0, 1, 4);
 
-        mApplyBeforeOut
-            = new QCheckBox(i18n("Apply this filter &before sending messages"), mAdvOptsGroup);
+        mApplyBeforeOut = new QCheckBox(i18n("Apply this filter &before sending messages"), mAdvOptsGroup);
         mApplyBeforeOut->setToolTip(
             i18n("<p>The filter will be triggered <b>before</b> the message is sent "
                  "and it will affect both the local copy and the sent copy of the message.</p>"
                  "<p>This is required if the recipient's copy also needs to be modified.</p>"));
-        gl->addWidget(mApplyBeforeOut, 5, 0, 1, 4);
+        gl->addWidget(mApplyBeforeOut, 6, 0, 1, 4);
 
-        mApplyOnCtrlJ
-            = new QCheckBox(i18n("Apply this filter on manual &filtering"), mAdvOptsGroup);
-        gl->addWidget(mApplyOnCtrlJ, 6, 0, 1, 4);
+        mApplyOnCtrlJ = new QCheckBox(i18n("Apply this filter on manual &filtering"), mAdvOptsGroup);
+        gl->addWidget(mApplyOnCtrlJ, 7, 0, 1, 4);
 
         mApplyOnAllFolders = new QCheckBox(i18n("Apply this filter on inbound emails in all folders"), mAdvOptsGroup);
-        mApplyOnAllFolders->setToolTip(i18n("<p>The filter will be applied on inbound emails from all folders "
-                                            "belonging to all accounts selected above. This is useful when using local filters "
-                                            "with IMAP accounts where new emails may have already been moved to different folders "
-                                            "by server-side filters.</p>"));
-        gl->addWidget(mApplyOnAllFolders, 7, 0, 1, 4);
+        mApplyOnAllFolders->setToolTip(
+            i18n("<p>The filter will be applied on inbound emails from all folders "
+                 "belonging to all accounts selected above. This is useful when using local filters "
+                 "with IMAP accounts where new emails may have already been moved to different folders "
+                 "by server-side filters.</p>"));
+        gl->addWidget(mApplyOnAllFolders, 8, 0, 1, 4);
 
-        mStopProcessingHere
-            = new QCheckBox(i18n("If this filter &matches, stop processing here"), mAdvOptsGroup);
-        gl->addWidget(mStopProcessingHere, 8, 0, 1, 4);
+        mStopProcessingHere = new QCheckBox(i18n("If this filter &matches, stop processing here"), mAdvOptsGroup);
+        gl->addWidget(mStopProcessingHere, 9, 0, 1, 4);
 
-        mConfigureShortcut
-            = new QCheckBox(i18n("Add this filter to the Apply Filter menu"), mAdvOptsGroup);
-        gl->addWidget(mConfigureShortcut, 9, 0, 1, 2);
+        mConfigureShortcut = new QCheckBox(i18n("Add this filter to the Apply Filter menu"), mAdvOptsGroup);
+        gl->addWidget(mConfigureShortcut, 10, 0, 1, 2);
 
-        QLabel *keyButtonLabel = new QLabel(i18n("Shortcut:"), mAdvOptsGroup);
-        keyButtonLabel->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
-        gl->addWidget(keyButtonLabel, 9, 2, 1, 1);
+        mInMenuWidget = new QWidget(mAdvOptsGroup);
+        mInMenuWidget->setContentsMargins(20, 0, 0, 0);
+        gl->addWidget(mInMenuWidget, 11, 0, 1, 4);
+        auto inMenuLayout = new QFormLayout(mInMenuWidget);
 
-        mKeySeqWidget = new KKeySequenceWidget(mAdvOptsGroup);
+        connect(mConfigureShortcut, &QCheckBox::toggled, this, [this](bool aChecked) {
+            if (mFilter) {
+                mFilter->setConfigureShortcut(aChecked);
+                mInMenuWidget->setEnabled(aChecked);
+
+                // Enable the apply button
+                slotDialogUpdated();
+            }
+        });
+
+        mConfigureToolbar = new QCheckBox(i18n("Additionally add this filter to the toolbar"), mInMenuWidget);
+        inMenuLayout->addRow(mConfigureToolbar);
+
+        mKeySeqWidget = new KKeySequenceWidget(mInMenuWidget);
         mKeySeqWidget->setObjectName(QStringLiteral("FilterShortcutSelector"));
-        gl->addWidget(mKeySeqWidget, 9, 3, 1, 1);
-        mKeySeqWidget->setEnabled(false);
         mKeySeqWidget->setModifierlessAllowed(true);
         mKeySeqWidget->setCheckActionCollections(actionCollection);
+        inMenuLayout->addRow(i18n("Shortcut:"), mKeySeqWidget);
 
-        mConfigureToolbar
-            = new QCheckBox(i18n("Additionally add this filter to the toolbar"), mAdvOptsGroup);
-        gl->addWidget(mConfigureToolbar, 10, 0, 1, 4);
-        mConfigureToolbar->setEnabled(false);
-
-        QWidget *hbox = new QWidget(mAdvOptsGroup);
-        QHBoxLayout *hboxHBoxLayout = new QHBoxLayout(hbox);
-        hboxHBoxLayout->setMargin(0);
-        mFilterActionLabel = new QLabel(i18n("Icon for this filter:"), hbox);
-        hboxHBoxLayout->addWidget(mFilterActionLabel);
-        mFilterActionLabel->setEnabled(false);
-
-        mFilterActionIconButton = new KIconButton(hbox);
-        hboxHBoxLayout->addWidget(mFilterActionIconButton);
-        mFilterActionLabel->setBuddy(mFilterActionIconButton);
+        mFilterActionIconButton = new KIconButton(mInMenuWidget);
         mFilterActionIconButton->setIconType(KIconLoader::NoGroup, KIconLoader::Action, false);
         mFilterActionIconButton->setIconSize(16);
         mFilterActionIconButton->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
-        mFilterActionIconButton->setEnabled(false);
-
-        gl->addWidget(hbox, 11, 0, 1, 4);
+        inMenuLayout->addRow(i18n("Icon for this filter:"), mFilterActionIconButton);
 
         mAdvOptsGroup->setLayout(gl);
+        mInMenuWidget->setEnabled(false);
     }
     vbl2->addWidget(mAdvOptsGroup, 0, Qt::AlignTop);
 
-    QHBoxLayout *applySpecificFiltersLayout = new QHBoxLayout;
-    QLabel *lab = new QLabel(i18n("Run selected filter(s) on: "), this);
+    auto applySpecificFiltersLayout = new QHBoxLayout;
+    auto lab = new QLabel(i18n("Run selected filter(s) on: "), this);
     applySpecificFiltersLayout->addWidget(lab);
     mFolderRequester = new MailCommon::FolderRequester(this);
     mFolderRequester->setNotAllowToCreateNewFolder(true);
     applySpecificFiltersLayout->addWidget(mFolderRequester);
-    connect(mFolderRequester, &FolderRequester::folderChanged,
-            this, &KMFilterDialog::slotFolderChanged);
+    connect(mFolderRequester, &FolderRequester::folderChanged, this, &KMFilterDialog::slotFolderChanged);
     mRunNow = new QPushButton(i18n("Run Now"), this);
     mRunNow->setEnabled(false);
     applySpecificFiltersLayout->addWidget(mRunNow);
@@ -350,8 +316,6 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
     // check box to the filter
     connect(mStopProcessingHere, &QCheckBox::toggled, this, &KMFilterDialog::slotStopProcessingButtonToggled);
 
-    connect(mConfigureShortcut, &QCheckBox::toggled, this, &KMFilterDialog::slotConfigureShortcutButtonToggled);
-
     connect(mKeySeqWidget, &KKeySequenceWidget::keySequenceChanged, this, &KMFilterDialog::slotShortcutChanged);
 
     connect(mConfigureToolbar, &QCheckBox::toggled, this, &KMFilterDialog::slotConfigureToolbarButtonToggled);
@@ -367,30 +331,24 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
     connect(mPatternEdit, &MailCommon::SearchPatternEdit::maybeNameChanged, mFilterList, &KMFilterListBox::slotUpdateFilterName);
 
     // save filters on 'Apply' or 'OK'
-    connect(mApplyButton, &QAbstractButton::clicked,
-            this, &KMFilterDialog::slotApply);
+    connect(mApplyButton, &QAbstractButton::clicked, this, &KMFilterDialog::slotApply);
 
     // save dialog size on 'OK'
-    connect(okButton, &QAbstractButton::clicked,
-            this, &KMFilterDialog::slotSaveSize);
+    connect(okButton, &QAbstractButton::clicked, this, &KMFilterDialog::slotSaveSize);
 
     // destruct the dialog on close and Cancel
-    connect(buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked,
-            this, &KMFilterDialog::slotFinished);
+    connect(buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked, this, &KMFilterDialog::slotFinished);
 
     // disable closing when user wants to continue editing
-    connect(mFilterList, &KMFilterListBox::abortClosing,
-            this, &KMFilterDialog::slotDisableAccept);
+    connect(mFilterList, &KMFilterListBox::abortClosing, this, &KMFilterDialog::slotDisableAccept);
 
     connect(mFilterList, &KMFilterListBox::filterCreated, this, &KMFilterDialog::slotDialogUpdated);
-    connect(mFilterList, &KMFilterListBox::filterRemoved,
-            this, &KMFilterDialog::slotDialogUpdated);
-    connect(mFilterList, &KMFilterListBox::filterUpdated,
-            this, &KMFilterDialog::slotDialogUpdated);
+    connect(mFilterList, &KMFilterListBox::filterRemoved, this, &KMFilterDialog::slotDialogUpdated);
+    connect(mFilterList, &KMFilterListBox::filterUpdated, this, &KMFilterDialog::slotDialogUpdated);
     connect(mFilterList, &KMFilterListBox::filterOrderAltered, this, &KMFilterDialog::slotDialogUpdated);
     connect(mPatternEdit, &MailCommon::SearchPatternEdit::patternChanged, this, &KMFilterDialog::slotDialogUpdated);
-    connect(mActionLister, QOverload<QWidget *>::of(&FilterActionWidgetLister::widgetAdded), this, &KMFilterDialog::slotDialogUpdated);
-    connect(mActionLister, QOverload<QWidget *>::of(&FilterActionWidgetLister::widgetRemoved), this, &KMFilterDialog::slotDialogUpdated);
+    connect(mActionLister, qOverload<QWidget *>(&FilterActionWidgetLister::widgetAdded), this, &KMFilterDialog::slotDialogUpdated);
+    connect(mActionLister, qOverload<QWidget *>(&FilterActionWidgetLister::widgetRemoved), this, &KMFilterDialog::slotDialogUpdated);
     connect(mActionLister, &MailCommon::FilterActionWidgetLister::filterModified, this, &KMFilterDialog::slotDialogUpdated);
     connect(mActionLister, &MailCommon::FilterActionWidgetLister::clearWidgets, this, &KMFilterDialog::slotDialogUpdated);
     KConfigGroup myGroup(KernelIf->config(), "Geometry");
@@ -429,7 +387,7 @@ bool KMFilterDialog::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->ignore();
             return true;
@@ -457,46 +415,36 @@ void KMFilterDialog::slotFolderChanged(const Akonadi::Collection &collection)
 void KMFilterDialog::slotRunFilters()
 {
     if (!mFolderRequester->collection().isValid()) {
-        KMessageBox::information(
-            this,
-            i18nc("@info",
-                  "Unable to apply this filter since there are no folders selected."),
-            i18n("No folder selected."));
+        KMessageBox::information(this, i18nc("@info", "Unable to apply this filter since there are no folders selected."), i18n("No folder selected."));
         return;
     }
 
     if (mApplyButton->isEnabled()) {
-        KMessageBox::information(
-            this,
-            i18nc("@info",
-                  "Some filters were changed and not saved yet. "
-                  "You must save your filters before they can be applied."),
-            i18n("Filters changed."));
+        KMessageBox::information(this,
+                                 i18nc("@info",
+                                       "Some filters were changed and not saved yet. "
+                                       "You must save your filters before they can be applied."),
+                                 i18n("Filters changed."));
         return;
     }
     SearchRule::RequiredPart requiredPart = SearchRule::Envelope;
     const QStringList selectedFiltersId = mFilterList->selectedFilterId(requiredPart, mFolderRequester->collection().resource());
     if (selectedFiltersId.isEmpty()) {
-        KMessageBox::information(
-            this,
-            i18nc("@info",
-                  "Unable to apply a filter since there are no filters currently selected."),
-            i18n("No filters selected."));
+        KMessageBox::information(this, i18nc("@info", "Unable to apply a filter since there are no filters currently selected."), i18n("No filters selected."));
         return;
     }
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(mFolderRequester->collection(), this);
+    auto job = new Akonadi::ItemFetchJob(mFolderRequester->collection(), this);
     job->setProperty("requiredPart", QVariant::fromValue(requiredPart));
     job->setProperty("listFilters", QVariant::fromValue(selectedFiltersId));
 
-    connect(job, &KJob::result,
-            this, &KMFilterDialog::slotFetchItemsForFolderDone);
+    connect(job, &KJob::result, this, &KMFilterDialog::slotFetchItemsForFolderDone);
 
-    mRunNow->setEnabled(false);   //Disable it
+    mRunNow->setEnabled(false); // Disable it
 }
 
 void KMFilterDialog::slotFetchItemsForFolderDone(KJob *job)
 {
-    Akonadi::ItemFetchJob *fjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto fjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     Q_ASSERT(fjob);
 
     QStringList filtersId;
@@ -569,8 +517,7 @@ void KMFilterDialog::slotFilterSelected(MailFilter *aFilter)
     mApplyOnCtrlJ->setChecked(applyOnExplicit);
     mStopProcessingHere->setChecked(stopHere);
     mConfigureShortcut->setChecked(configureShortcut);
-    mKeySeqWidget->setKeySequence(shortcut,
-                                  KKeySequenceWidget::NoValidate);
+    mKeySeqWidget->setKeySequence(shortcut, KKeySequenceWidget::NoValidate);
     mConfigureToolbar->setChecked(configureToolbar);
     mFilterActionIconButton->setIcon(icon);
     mIgnoreFilterUpdates = false;
@@ -622,12 +569,9 @@ void KMFilterDialog::slotApplicabilityChanged()
         // Enable the apply button
         slotDialogUpdated();
 
-        qCDebug(MAILCOMMON_LOG) << "Setting filter to be applied at"
-                                << (mFilter->applyOnInbound() ? "incoming " : "")
-                                << (mFilter->applyOnOutbound() ? "outgoing " : "")
-                                << (mFilter->applyBeforeOutbound() ? "before_outgoing " : "")
-                                << (mFilter->applyOnAllFoldersInbound() ? "all folders inboud " : "")
-                                << (mFilter->applyOnExplicit() ? "explicit CTRL-J" : "");
+        qCDebug(MAILCOMMON_LOG) << "Setting filter to be applied at" << (mFilter->applyOnInbound() ? "incoming " : "")
+                                << (mFilter->applyOnOutbound() ? "outgoing " : "") << (mFilter->applyBeforeOutbound() ? "before_outgoing " : "")
+                                << (mFilter->applyOnAllFoldersInbound() ? "all folders inboud " : "") << (mFilter->applyOnExplicit() ? "explicit CTRL-J" : "");
     }
 }
 
@@ -658,20 +602,6 @@ void KMFilterDialog::slotStopProcessingButtonToggled(bool aChecked)
     }
 }
 
-void KMFilterDialog::slotConfigureShortcutButtonToggled(bool aChecked)
-{
-    if (mFilter) {
-        mFilter->setConfigureShortcut(aChecked);
-        mKeySeqWidget->setEnabled(aChecked);
-        mConfigureToolbar->setEnabled(aChecked);
-        mFilterActionIconButton->setEnabled(aChecked);
-        mFilterActionLabel->setEnabled(aChecked);
-
-        // Enable the apply button
-        slotDialogUpdated();
-    }
-}
-
 void KMFilterDialog::slotShortcutChanged(const QKeySequence &newSeq)
 {
     if (mFilter) {
@@ -718,7 +648,7 @@ void KMFilterDialog::importFilters(MailCommon::FilterImporterExporter::FilterTyp
     MailCommon::FilterImporterPathCache::self()->clear();
     FilterImporterExporter importer(this);
     bool canceled = false;
-    QList<MailFilter *> filters = importer.importFilters(canceled, type);
+    QVector<MailFilter *> filters = importer.importFilters(canceled, type);
     if (canceled) {
         return;
     }
@@ -728,27 +658,22 @@ void KMFilterDialog::importFilters(MailCommon::FilterImporterExporter::FilterTyp
         return;
     }
     QStringList listOfFilter;
-    QList<MailFilter *>::ConstIterator end(filters.constEnd());
+    QVector<MailFilter *>::ConstIterator end(filters.constEnd());
 
-    for (QList<MailFilter *>::ConstIterator it = filters.constBegin(); it != end; ++it) {
-        mFilterList->appendFilter(*it);   // no need to deep copy, ownership passes to the list
+    for (QVector<MailFilter *>::ConstIterator it = filters.constBegin(); it != end; ++it) {
+        mFilterList->appendFilter(*it); // no need to deep copy, ownership passes to the list
         listOfFilter << (*it)->name();
     }
 
-    KMessageBox::informationList(
-        this,
-        i18n("Filters which were imported:"),
-        listOfFilter);
+    KMessageBox::informationList(this, i18n("Filters which were imported:"), listOfFilter);
 }
 
 void KMFilterDialog::slotExportFilters()
 {
     bool wasCanceled = false;
-    const QList<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
+    const QVector<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
     if (filters.isEmpty()) {
-        KMessageBox::information(
-            this,
-            i18n("Any filter found."));
+        KMessageBox::information(this, i18n("Any filter found."));
         return;
     }
     if (wasCanceled) {
@@ -775,17 +700,18 @@ void KMFilterDialog::slotDialogUpdated()
 void KMFilterDialog::slotExportAsSieveScript()
 {
     if (mApplyButton->isEnabled()) {
-        KMessageBox::information(
-            this,
-            i18nc("@info",
-                  "Some filters were changed and not saved yet.<br>"
-                  "You must save your filters before they can be exported."),
-            i18n("Filters changed."));
+        KMessageBox::information(this,
+                                 i18nc("@info",
+                                       "Some filters were changed and not saved yet.<br>"
+                                       "You must save your filters before they can be exported."),
+                                 i18n("Filters changed."));
         return;
     }
-    KMessageBox::information(this, i18n("We cannot convert all KMail filters to sieve scripts but we can try :)"), i18n("Convert KMail filters to sieve scripts"));
+    KMessageBox::information(this,
+                             i18n("We cannot convert all KMail filters to sieve scripts but we can try :)"),
+                             i18n("Convert KMail filters to sieve scripts"));
     bool wasCanceled = false;
-    const QList<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
+    const QVector<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
     if (filters.isEmpty()) {
         return;
     }
@@ -793,7 +719,7 @@ void KMFilterDialog::slotExportAsSieveScript()
         QPointer<FilterSelectionDialog> dlg = new FilterSelectionDialog(this);
         dlg->setFilters(filters);
         if (dlg->exec() == QDialog::Accepted) {
-            QList<MailFilter *> lst = dlg->selectedFilters();
+            QVector<MailFilter *> lst = dlg->selectedFilters();
             if (!lst.isEmpty()) {
                 FilterConvertToSieve convert(lst);
                 convert.convert();
