@@ -1,31 +1,24 @@
 /*
   kmfawidgets.h - KMFilterAction parameter widgets
-  Copyright (c) 2001 Marc Mutz <mutz@kde.org>
+  SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SOUNDTESTWIDGET_H
-#define MAILCOMMON_SOUNDTESTWIDGET_H
+#pragma once
 
 #include <QWidget>
 
+namespace Phonon
+{
+class MediaObject;
+}
+
 class QPushButton;
 class KUrlRequester;
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @short A widget to play a sound from a given URL.
  */
@@ -44,7 +37,7 @@ public:
     /**
      * Destroys the sound test widget.
      */
-    ~SoundTestWidget();
+    ~SoundTestWidget() override;
 
     /**
      * Sets the @p url of the sound file to play.
@@ -80,7 +73,7 @@ private:
     void slotUrlChanged(const QString &);
     KUrlRequester *m_urlRequester = nullptr;
     QPushButton *m_playButton = nullptr;
+    Phonon::MediaObject *m_player = nullptr;
 };
 }
 
-#endif
