@@ -1,39 +1,27 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterimporterexportergui.h"
-#include "filter/filterimporterexporter.h"
 #include "filter/mailfilter.h"
 
 #include <QApplication>
-#include <QVBoxLayout>
 #include <QMenu>
 #include <QMenuBar>
 #include <QTextEdit>
+#include <QVBoxLayout>
 
 Q_DECLARE_METATYPE(MailCommon::FilterImporterExporter::FilterType)
 FilterImporterExporterGui::FilterImporterExporterGui(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QMenuBar *menuBar = new QMenuBar(this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto menuBar = new QMenuBar(this);
     mainLayout->addWidget(menuBar);
     QMenu *menuFilter = menuBar->addMenu(QStringLiteral("filter"));
-    QAction *act = new QAction(QStringLiteral("KMail filters"), this);
+    auto act = new QAction(QStringLiteral("KMail filters"), this);
     act->setData(QVariant::fromValue(MailCommon::FilterImporterExporter::KMailFilter));
     menuFilter->addAction(act);
 
@@ -68,7 +56,7 @@ FilterImporterExporterGui::FilterImporterExporterGui(QWidget *parent)
     act = new QAction(QStringLiteral("GMail filters"), this);
     act->setData(QVariant::fromValue(MailCommon::FilterImporterExporter::GmailFilter));
     menuFilter->addAction(act);
-    connect(menuFilter, QOverload<QAction *>::of(&QMenu::triggered), this, &FilterImporterExporterGui::slotImportFilter);
+    connect(menuFilter, &QMenu::triggered, this, &FilterImporterExporterGui::slotImportFilter);
 
     mTextEdit = new QTextEdit;
     mTextEdit->setReadOnly(true);
@@ -109,7 +97,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    FilterImporterExporterGui *w = new FilterImporterExporterGui();
+    auto w = new FilterImporterExporterGui();
     w->resize(800, 600);
     w->show();
     app.exec();
