@@ -1,29 +1,19 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_ENTITYCOLLECTIONORDERPROXYMODEL_H
-#define MAILCOMMON_ENTITYCOLLECTIONORDERPROXYMODEL_H
+#pragma once
 
 #include "mailcommon_export.h"
-#include <EntityOrderProxyModel>
+#include <Akonadi/EntityOrderProxyModel>
+
+namespace MailCommon
+{
+class HierarchicalFolderMatcher;
 
-namespace MailCommon {
 /**
  * @brief The EntityCollectionOrderProxyModel class implements ordering of mail collections.
  * It supports two modes: manual sorting and automatic sorting.
@@ -53,13 +43,17 @@ public:
     void clearRanks();
     void setTopLevelOrder(const QStringList &list);
 
+    void setFolderMatcher(const HierarchicalFolderMatcher &matcher);
+
 public Q_SLOTS:
     void slotSpecialCollectionsChanged();
 
+protected:
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
+
 private:
     class EntityCollectionOrderProxyModelPrivate;
-    EntityCollectionOrderProxyModelPrivate *const d;
+    std::unique_ptr<EntityCollectionOrderProxyModelPrivate> const d;
 };
 }
 
-#endif
