@@ -1,48 +1,36 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "foldersettings.h"
 #include "kernel/mailkernel.h"
+#include "mailcommon_debug.h"
 #include "util/mailutil.h"
 #include "util/resourcereadconfigfile.h"
-#include <PimCommon/PimUtil>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <Akonadi/KMime/NewMailNotifierAttribute>
-#include "mailcommon_debug.h"
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <CollectionModifyJob>
+#include <PimCommon/PimUtil>
 
 using namespace Akonadi;
 
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
 #include <QMutex>
 #include <QMutexLocker>
 #include <QSharedPointer>
 
-namespace MailCommon {
+namespace MailCommon
+{
 static QMutex mapMutex;
-static QMap<Collection::Id, QSharedPointer<FolderSettings> > fcMap;
+static QMap<Collection::Id, QSharedPointer<FolderSettings>> fcMap;
 
-QSharedPointer<FolderSettings> FolderSettings::forCollection(
-    const Akonadi::Collection &coll, bool writeConfig)
+QSharedPointer<FolderSettings> FolderSettings::forCollection(const Akonadi::Collection &coll, bool writeConfig)
 {
     QMutexLocker lock(&mapMutex);
 
@@ -69,13 +57,12 @@ FolderSettings::FolderSettings(const Akonadi::Collection &col, bool writeconfig)
     mIdentity = KernelIf->identityManager()->defaultIdentity().uoid();
 
     readConfig();
-    connect(KernelIf->identityManager(), QOverload<>::of(&KIdentityManagement::IdentityManager::changed),
-            this, &FolderSettings::slotIdentitiesChanged);
+    connect(KernelIf->identityManager(), qOverload<>(&KIdentityManagement::IdentityManager::changed), this, &FolderSettings::slotIdentitiesChanged);
 }
 
 FolderSettings::~FolderSettings()
 {
-    //qCDebug(MAILCOMMON_LOG)<<" FolderCollection::~FolderCollection"<<this;
+    // qCDebug(MAILCOMMON_LOG)<<" FolderCollection::~FolderCollection"<<this;
     if (mWriteConfig) {
         writeConfig();
     }
@@ -100,7 +87,7 @@ void FolderSettings::clearCache()
 void FolderSettings::resetHtmlFormat()
 {
     QMutexLocker lock(&mapMutex);
-    QMap<Collection::Id, QSharedPointer<FolderSettings> >::const_iterator i = fcMap.constBegin();
+    QMap<Collection::Id, QSharedPointer<FolderSettings>>::const_iterator i = fcMap.constBegin();
     while (i != fcMap.constEnd()) {
         i.value()->setFormatMessage(MessageViewer::Viewer::UseGlobalSetting);
         ++i;
@@ -203,11 +190,11 @@ void FolderSettings::readConfig()
 
     if (configGroup.hasKey(QStringLiteral("IgnoreNewMail"))) {
         if (configGroup.readEntry(QStringLiteral("IgnoreNewMail"), false)) {
-            //migrate config.
-            Akonadi::NewMailNotifierAttribute *newMailNotifierAttr = mCollection.attribute<Akonadi::NewMailNotifierAttribute>(Akonadi::Collection::AddIfMissing);
+            // migrate config.
+            auto *newMailNotifierAttr = mCollection.attribute<Akonadi::NewMailNotifierAttribute>(Akonadi::Collection::AddIfMissing);
             newMailNotifierAttr->setIgnoreNewMail(true);
             new Akonadi::CollectionModifyJob(mCollection, this);
-            //TODO verify if it works;
+            // TODO verify if it works;
         }
         configGroup.deleteEntry("IgnoreNewMail");
     }
@@ -218,8 +205,8 @@ void FolderSettings::readConfig()
         setShortcut(sc);
     }
 
-    mFormatMessage = static_cast<MessageViewer::Viewer::DisplayFormatMessage>(configGroup.readEntry("displayFormatOverride",
-                                                                                                    static_cast<int>(MessageViewer::Viewer::UseGlobalSetting)));
+    mFormatMessage = static_cast<MessageViewer::Viewer::DisplayFormatMessage>(
+        configGroup.readEntry("displayFormatOverride", static_cast<int>(MessageViewer::Viewer::UseGlobalSetting)));
 
     mFolderHtmlLoadExtPreference = configGroup.readEntry("htmlLoadExternalOverride", false);
 }
@@ -367,8 +354,7 @@ uint FolderSettings::fallBackIdentity() const
             identityId = remoteAccountIdent;
         }
     }
-    if (identityId != -1
-        && !KernelIf->identityManager()->identityForUoid(identityId).isNull()) {
+    if (identityId != -1 && !KernelIf->identityManager()->identityForUoid(identityId).isNull()) {
         return identityId;
     }
     return mIdentity;
