@@ -1,42 +1,29 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "foldertreewidget.h"
 #include "entitycollectionorderproxymodel.h"
 #include "foldertreeview.h"
-#include "foldertreewidgetproxymodel.h"
+#include "hierarchicalfoldermatcher_p.h"
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
 
-#include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommon/PimUtil>
+#include <PimCommonAkonadi/ImapAclAttribute>
 
-#include <AkonadiCore/AttributeFactory>
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/StatisticsProxyModel>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/StatisticsProxyModel>
 
-#include <AkonadiWidgets/EntityTreeView>
-#include <AkonadiWidgets/ETMViewStateSaver>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityTreeView>
 
 #include <KMime/Message>
 
@@ -45,20 +32,18 @@
 #include <KLocalizedString>
 
 #include <QFontDatabase>
+#include <QHeaderView>
 #include <QKeyEvent>
-#include <QLineEdit>
 #include <QLabel>
+#include <QLineEdit>
 #include <QPointer>
 #include <QVBoxLayout>
 
-namespace MailCommon {
+namespace MailCommon
+{
 class Q_DECL_HIDDEN FolderTreeWidget::FolderTreeWidgetPrivate
 {
 public:
-    FolderTreeWidgetPrivate()
-    {
-    }
-
     QString filter;
     QString oldFilterStr;
     Akonadi::StatisticsProxyModel *filterModel = nullptr;
@@ -73,8 +58,10 @@ public:
     bool dontKeyFilter = false;
 };
 
-FolderTreeWidget::FolderTreeWidget(
-    QWidget *parent, KXMLGUIClient *xmlGuiClient, FolderTreeWidget::TreeViewOptions options, FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModelOptions optReadableProxy)
+FolderTreeWidget::FolderTreeWidget(QWidget *parent,
+                                   KXMLGUIClient *xmlGuiClient,
+                                   FolderTreeWidget::TreeViewOptions options,
+                                   FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModelOptions optReadableProxy)
     : QWidget(parent)
     , d(new FolderTreeWidgetPrivate())
 {
@@ -85,8 +72,8 @@ FolderTreeWidget::FolderTreeWidget(
 
     connect(d->folderTreeView, &FolderTreeView::manualSortingChanged, this, &FolderTreeWidget::slotManualSortingChanged);
 
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QVBoxLayout(this);
+    lay->setContentsMargins({});
 
     d->label = new QLabel(i18n("You can start typing to filter the list of folders."), this);
     lay->addWidget(d->label);
@@ -94,20 +81,20 @@ FolderTreeWidget::FolderTreeWidget(
     d->filterFolderLineEdit = new QLineEdit(this);
 
     d->filterFolderLineEdit->setClearButtonEnabled(true);
-    d->filterFolderLineEdit->setPlaceholderText(
-        i18nc("@info Displayed grayed-out inside the textbox, verb to search",
-              "Search"));
+    d->filterFolderLineEdit->setPlaceholderText(i18nc("@info Displayed grayed-out inside the textbox, verb to search", "Search"));
     lay->addWidget(d->filterFolderLineEdit);
 
     if (!(options & HideStatistics)) {
         d->filterModel = new Akonadi::StatisticsProxyModel(this);
         d->filterModel->setSourceModel(KernelIf->collectionModel());
     }
+    if (options & HideHeaderViewMenu) {
+        d->folderTreeView->header()->setContextMenuPolicy(Qt::NoContextMenu);
+    }
 
     d->readableproxy = new FolderTreeWidgetProxyModel(this, optReadableProxy);
-    d->readableproxy->setSourceModel((options & HideStatistics)
-                                     ? static_cast<QAbstractItemModel *>(KernelIf->collectionModel())
-                                     : static_cast<QAbstractItemModel *>(d->filterModel));
+    d->readableproxy->setSourceModel((options & HideStatistics) ? static_cast<QAbstractItemModel *>(KernelIf->collectionModel())
+                                                                : static_cast<QAbstractItemModel *>(d->filterModel));
     d->readableproxy->addContentMimeTypeInclusionFilter(KMime::Message::mimeType());
 
     connect(d->folderTreeView, &FolderTreeView::changeTooltipsPolicy, this, &FolderTreeWidget::slotChangeTooltipsPolicy);
@@ -116,7 +103,7 @@ FolderTreeWidget::FolderTreeWidget(
     d->folderTreeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     d->folderTreeView->installEventFilter(this);
 
-    //Order proxy
+    // Order proxy
     d->entityOrderProxy = new EntityCollectionOrderProxyModel(this);
     d->entityOrderProxy->setSourceModel(d->readableproxy);
     d->entityOrderProxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
@@ -141,16 +128,13 @@ FolderTreeWidget::FolderTreeWidget(
     }
 }
 
-FolderTreeWidget::~FolderTreeWidget()
-{
-    delete d;
-}
+FolderTreeWidget::~FolderTreeWidget() = default;
 
 void FolderTreeWidget::slotFilterFixedString(const QString &text)
 {
     delete d->saver;
     if (d->oldFilterStr.isEmpty()) {
-        //Save it.
+        // Save it.
         Akonadi::ETMViewStateSaver saver;
         saver.setView(folderTreeView());
         d->expandedItems = saver.expansionKeys();
@@ -178,13 +162,14 @@ void FolderTreeWidget::disableContextMenuAndExtraColumn()
     d->folderTreeView->disableContextMenuAndExtraColumn();
 }
 
-void FolderTreeWidget::selectCollectionFolder(const Akonadi::Collection &collection)
+void FolderTreeWidget::selectCollectionFolder(const Akonadi::Collection &collection, bool expand)
 {
-    const QModelIndex index
-        = Akonadi::EntityTreeModel::modelIndexForCollection(d->folderTreeView->model(), collection);
+    const QModelIndex index = Akonadi::EntityTreeModel::modelIndexForCollection(d->folderTreeView->model(), collection);
 
     d->folderTreeView->setCurrentIndex(index);
-    d->folderTreeView->setExpanded(index, true);
+    if (expand) {
+        d->folderTreeView->setExpanded(index, true);
+    }
     d->folderTreeView->scrollTo(index);
 }
 
@@ -229,9 +214,7 @@ Akonadi::Collection::List FolderTreeWidget::selectedCollections() const
     const QModelIndexList selectedIndexes = selectionModel->selectedIndexes();
     for (const QModelIndex &index : selectedIndexes) {
         if (index.isValid()) {
-            const Akonadi::Collection collection
-                = index.model()->data(
-                      index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const auto collection = index.model()->data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid()) {
                 collections.append(collection);
             }
@@ -291,7 +274,7 @@ void FolderTreeWidget::changeToolTipsPolicyConfig(ToolTipDisplayPolicy policy)
 {
     switch (policy) {
     case DisplayAlways:
-    case DisplayWhenTextElided: //Need to implement in the future
+    case DisplayWhenTextElided: // Need to implement in the future
         if (d->filterModel) {
             d->filterModel->setToolTipEnabled(true);
         }
@@ -326,22 +309,19 @@ QLineEdit *FolderTreeWidget::filterFolderLineEdit() const
 
 void FolderTreeWidget::applyFilter(const QString &filter)
 {
-    d->label->setText(
-        filter.isEmpty()
-        ? i18n("You can start typing to filter the list of folders.")
-        : i18n("Path: (%1)", filter));
+    d->label->setText(filter.isEmpty() ? i18n("You can start typing to filter the list of folders.") : i18n("Path: (%1)", filter));
 
-    d->entityOrderProxy->setFilterWildcard(filter);
+    HierarchicalFolderMatcher matcher;
+    matcher.setFilter(filter, d->entityOrderProxy->filterCaseSensitivity());
+    d->entityOrderProxy->setFolderMatcher(matcher);
     d->folderTreeView->expandAll();
-    QAbstractItemModel *model = d->folderTreeView->model();
-    QModelIndex current = d->folderTreeView->currentIndex();
-    QModelIndex start = current.isValid() ? current : model->index(0, 0);
-    QModelIndexList list = model->match(start, Qt::DisplayRole, d->filter, 1 /* stop at first hit */,
-                                        Qt::MatchContains | Qt::MatchWrap | Qt::MatchRecursive);
-    if (!list.isEmpty()) {
-        current = list.first();
-        d->folderTreeView->setCurrentIndex(current);
-        d->folderTreeView->scrollTo(current);
+    const QAbstractItemModel *const model = d->folderTreeView->model();
+    const QModelIndex current = d->folderTreeView->currentIndex();
+    const QModelIndex start = current.isValid() ? current : model->index(0, 0);
+    const QModelIndex firstMatch = matcher.findFirstMatch(model, start);
+    if (firstMatch.isValid()) {
+        d->folderTreeView->setCurrentIndex(firstMatch);
+        d->folderTreeView->scrollTo(firstMatch);
     }
 }
 
@@ -363,7 +343,7 @@ void FolderTreeWidget::slotManualSortingChanged(bool active)
 
 bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
 {
-    Q_UNUSED(o);
+    Q_UNUSED(o)
     if (d->dontKeyFilter) {
         return false;
     }
@@ -371,8 +351,7 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
     if (e->type() == QEvent::KeyPress) {
         const QKeyEvent *const ke = static_cast<QKeyEvent *>(e);
         switch (ke->key()) {
-        case Qt::Key_Backspace:
-        {
+        case Qt::Key_Backspace: {
             const int filterLength(d->filter.length());
             if (filterLength > 0) {
                 d->filter.truncate(filterLength - 1);
@@ -384,8 +363,7 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
             d->filter.clear();
             applyFilter(d->filter);
             return false;
-        default:
-        {
+        default: {
             const QString s = ke->text();
             if (!s.isEmpty() && s.at(0).isPrint()) {
                 d->filter += s;
