@@ -1,34 +1,22 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FOLDERTREEWIDGET_H
-#define MAILCOMMON_FOLDERTREEWIDGET_H
+#pragma once
 
-#include "mailcommon_export.h"
 #include "foldertreewidgetproxymodel.h"
+#include "mailcommon_export.h"
 
-#include <Collection>
+#include <Akonadi/Collection>
 
 #include <QAbstractItemView>
 #include <QWidget>
-
-namespace Akonadi {
+#include <memory>
+namespace Akonadi
+{
 class StatisticsProxyModel;
 }
 
@@ -37,7 +25,8 @@ class KXMLGUIClient;
 
 class QItemSelectionModel;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class EntityCollectionOrderProxyModel;
 class FolderTreeView;
 
@@ -59,33 +48,35 @@ public:
         UseDistinctSelectionModel = 4,
         ShowCollectionStatisticAnimation = 8,
         DontKeyFilter = 16,
-        HideStatistics = 32
+        HideStatistics = 32,
+        HideHeaderViewMenu = 64
     };
     Q_DECLARE_FLAGS(TreeViewOptions, TreeViewOption)
 
-    explicit FolderTreeWidget(
-        QWidget *parent = nullptr, KXMLGUIClient *xmlGuiClient = nullptr, TreeViewOptions options = (TreeViewOptions)(ShowUnreadCount
-                                                                                                                      |ShowCollectionStatisticAnimation), FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModelOptions optReadableProxy = FolderTreeWidgetProxyModel::None);
-    ~FolderTreeWidget();
+    explicit FolderTreeWidget(QWidget *parent = nullptr,
+                              KXMLGUIClient *xmlGuiClient = nullptr,
+                              TreeViewOptions options = (TreeViewOptions)(ShowUnreadCount | ShowCollectionStatisticAnimation),
+                              FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModelOptions optReadableProxy = FolderTreeWidgetProxyModel::None);
+    ~FolderTreeWidget() override;
 
     /**
      * The possible tooltip display policies.
      */
     enum ToolTipDisplayPolicy {
-        DisplayAlways,           ///< Always display a tooltip when hovering over an item
-        DisplayWhenTextElided,   ///< Display the tooltip if the item text is actually elided
-        DisplayNever             ///< Nevery display tooltips
+        DisplayAlways, ///< Always display a tooltip when hovering over an item
+        DisplayWhenTextElided, ///< Display the tooltip if the item text is actually elided
+        DisplayNever ///< Nevery display tooltips
     };
 
     /**
      * The available sorting policies.
      */
     enum SortingPolicy {
-        SortByCurrentColumn,      ///< Columns are clickable, sorting is by the current column
-        SortByDragAndDropKey      ///< Columns are NOT clickable, sorting is done by drag and drop
+        SortByCurrentColumn, ///< Columns are clickable, sorting is by the current column
+        SortByDragAndDropKey ///< Columns are NOT clickable, sorting is done by drag and drop
     };
 
-    void selectCollectionFolder(const Akonadi::Collection &col);
+    void selectCollectionFolder(const Akonadi::Collection &col, bool expand = true);
 
     void setSelectionMode(QAbstractItemView::SelectionMode mode);
 
@@ -130,8 +121,7 @@ protected Q_SLOTS:
 private:
     bool eventFilter(QObject *o, QEvent *e) override;
     class FolderTreeWidgetPrivate;
-    FolderTreeWidgetPrivate *const d;
+    std::unique_ptr<FolderTreeWidgetPrivate> const d;
 };
 }
 
-#endif
