@@ -5,8 +5,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_INTERFACES_RULEWIDGETHANDLER_H
-#define MAILCOMMON_INTERFACES_RULEWIDGETHANDLER_H
+#pragma once
 
 #include "search/searchpattern.h"
 
@@ -14,11 +13,11 @@
 
 class QWidget;
 class QStackedWidget;
-class QByteArray;
 class QString;
 class QObject;
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @short An interface to filter/search rule widget handlers
  */
@@ -36,9 +35,9 @@ public:
     Q_REQUIRED_RESULT virtual QString prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const = 0;
     Q_REQUIRED_RESULT virtual bool handlesField(const QByteArray &field) const = 0;
     virtual void reset(QStackedWidget *functionStack, QStackedWidget *valueStack) const = 0;
-    Q_REQUIRED_RESULT virtual bool setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const MailCommon::SearchRule::Ptr rule, bool isAkonadiSearch) const = 0;
+    Q_REQUIRED_RESULT virtual bool
+    setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const MailCommon::SearchRule::Ptr rule, bool isAkonadiSearch) const = 0;
     Q_REQUIRED_RESULT virtual bool update(const QByteArray &field, QStackedWidget *functionStack, QStackedWidget *valueStack) const = 0;
 };
 }
 
-#endif
