@@ -1,31 +1,9 @@
 /**
- * Copyright (c) 2004 David Faure <faure@kde.org>
+ * SPDX-FileCopyrightText: 2004 David Faure <faure@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  In addition, as a special exception, the copyright holders give
- *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
- *  combinations including the two.  You must obey the GNU General
- *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
- *  your version of the file, but you are not obligated to do so.  If
- *  you do not wish to do so, delete this exception statement from
- *  your version.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
+
 #include "expirejob.h"
 #include "collectionpage/attributes/expirecollectionattribute.h"
 #include "kernel/mailkernel.h"
@@ -37,14 +15,14 @@ using PimCommon::BroadcastStatus;
 
 #include <KLocalizedString>
 
-#include <ItemDeleteJob>
-#include <ItemModifyJob>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <ItemMoveJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/ItemMoveJob>
+#include <Akonadi/KMime/MessageFlags>
 #include <Akonadi/KMime/MessageParts>
 #include <Akonadi/KMime/MessageStatus>
-#include <Akonadi/KMime/MessageFlags>
 #include <KMime/Message>
 
 /*
@@ -60,7 +38,7 @@ using PimCommon::BroadcastStatus;
   - Expire All Folders                              [KMMainWidget::slotExpireAll()]
 */
 
-namespace MailCommon {
+using namespace MailCommon;
 ExpireJob::ExpireJob(const Akonadi::Collection &folder, bool immediate)
     : ScheduledJob(folder, immediate)
 {
@@ -83,7 +61,9 @@ void ExpireJob::execute()
 
     const MailCommon::ExpireCollectionAttribute *expirationAttribute = mSrcFolder.attribute<MailCommon::ExpireCollectionAttribute>();
     if (expirationAttribute) {
-        int unreadDays, readDays;
+        int unreadDays;
+        int readDays;
+        mExpireMessagesWithoutInvalidDate = expirationAttribute->expireMessagesWithValidDate();
         expirationAttribute->daysToExpire(unreadDays, readDays);
 
         if (unreadDays > 0) {
@@ -111,7 +91,7 @@ void ExpireJob::execute()
 
 void ExpireJob::slotDoWork()
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(mSrcFolder, this);
+    auto job = new Akonadi::ItemFetchJob(mSrcFolder, this);
     job->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Envelope);
     connect(job, &Akonadi::ItemFetchJob::result, this, &ExpireJob::itemFetchResult);
 }
@@ -130,22 +110,23 @@ void ExpireJob::itemFetchResult(KJob *job)
             continue;
         }
 
-        const KMime::Message::Ptr mb = item.payload<KMime::Message::Ptr>();
+        const auto mb = item.payload<KMime::Message::Ptr>();
         Akonadi::MessageStatus status;
         status.setStatusFromFlags(item.flags());
-        if ((status.isImportant() || status.isToAct() || status.isWatched())
-            && SettingsIf->excludeImportantMailFromExpiry()) {
+        if ((status.isImportant() || status.isToAct() || status.isWatched()) && SettingsIf->excludeImportantMailFromExpiry()) {
             continue;
         }
 
-        time_t maxTime = status.isRead() ? mMaxReadTime : mMaxUnreadTime;
-
-        if (!mb->date(false)) {
-            continue;
-        }
-
-        if (mb->date()->dateTime().toSecsSinceEpoch() < maxTime) {
-            mRemovedMsgs.append(item);
+        auto mailDate = mb->date(false);
+        if (!mailDate) {
+            if (mExpireMessagesWithoutInvalidDate) {
+                mRemovedMsgs.append(item);
+            }
+        } else {
+            const time_t maxTime = status.isRead() ? mMaxReadTime : mMaxUnreadTime;
+            if (mailDate->dateTime().toSecsSinceEpoch() < maxTime) {
+                mRemovedMsgs.append(item);
+            }
         }
     }
 
@@ -167,34 +148,32 @@ void ExpireJob::done()
         if (expirationAttribute) {
             if (expirationAttribute->expireAction() == MailCommon::ExpireCollectionAttribute::ExpireDelete) {
                 // Expire by deletion, i.e. move to null target folder
-                qCDebug(MAILCOMMON_LOG) << "ExpireJob: finished expiring in folder"
-                                        << mSrcFolder.name()
-                                        << count << "messages to remove.";
-                Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(mRemovedMsgs, this);
+                qCDebug(MAILCOMMON_LOG) << "ExpireJob: finished expiring in folder" << mSrcFolder.name() << count << "messages to remove.";
+                auto job = new Akonadi::ItemDeleteJob(mRemovedMsgs, this);
                 connect(job, &Akonadi::ItemDeleteJob::result, this, &ExpireJob::slotExpireDone);
                 moving = true;
-                str = i18np("Removing 1 old message from folder %2...",
-                            "Removing %1 old messages from folder %2...",
-                            count, mSrcFolder.name());
+                str = i18np("Removing 1 old message from folder %2...", "Removing %1 old messages from folder %2...", count, mSrcFolder.name());
             } else {
                 // Expire by moving
                 mMoveToFolder = Kernel::self()->collectionFromId(expirationAttribute->expireToFolderId());
                 if (!mMoveToFolder.isValid()) {
-                    str = i18n("Cannot expire messages from folder %1: destination "
-                               "folder %2 not found",
-                               mSrcFolder.name(), expirationAttribute->expireToFolderId());
+                    str = i18n(
+                        "Cannot expire messages from folder %1: destination "
+                        "folder %2 not found",
+                        mSrcFolder.name(),
+                        expirationAttribute->expireToFolderId());
                     qCWarning(MAILCOMMON_LOG) << str;
                 } else {
-                    qCDebug(MAILCOMMON_LOG) << "ExpireJob: finished expiring in folder"
-                                            << mSrcFolder.name()
-                                            << mRemovedMsgs.count() << "messages to move to"
+                    qCDebug(MAILCOMMON_LOG) << "ExpireJob: finished expiring in folder" << mSrcFolder.name() << mRemovedMsgs.count() << "messages to move to"
                                             << mMoveToFolder.name();
-                    Akonadi::ItemMoveJob *job = new Akonadi::ItemMoveJob(mRemovedMsgs, mMoveToFolder, this);
+                    auto job = new Akonadi::ItemMoveJob(mRemovedMsgs, mMoveToFolder, this);
                     connect(job, &Akonadi::ItemMoveJob::result, this, &ExpireJob::slotMoveDone);
                     moving = true;
                     str = i18np("Moving 1 old message from folder %2 to folder %3...",
                                 "Moving %1 old messages from folder %2 to folder %3...",
-                                count, mSrcFolder.name(), mMoveToFolder.name());
+                                count,
+                                mSrcFolder.name(),
+                                mMoveToFolder.name());
                 }
             }
         }
@@ -213,7 +192,7 @@ void ExpireJob::slotMoveDone(KJob *job)
     if (job->error()) {
         qCCritical(MAILCOMMON_LOG) << job->error() << job->errorString();
     }
-    Akonadi::ItemMoveJob *itemjob = qobject_cast<Akonadi::ItemMoveJob *>(job);
+    auto itemjob = qobject_cast<Akonadi::ItemMoveJob *>(job);
     if (itemjob) {
         const Akonadi::Item::List lst = itemjob->items();
         if (!lst.isEmpty()) {
@@ -225,7 +204,7 @@ void ExpireJob::slotMoveDone(KJob *job)
                 }
             }
             if (!newLst.isEmpty()) {
-                Akonadi::ItemModifyJob *modifyJob = new Akonadi::ItemModifyJob(newLst, this);
+                auto modifyJob = new Akonadi::ItemModifyJob(newLst, this);
                 modifyJob->disableRevisionCheck();
                 connect(modifyJob, &Akonadi::ItemModifyJob::result, this, &ExpireJob::slotExpireDone);
             } else {
@@ -251,35 +230,33 @@ void ExpireJob::slotExpireDone(KJob *job)
         switch (error) {
         case KJob::NoError:
             if (expirationAttribute->expireAction() == MailCommon::ExpireCollectionAttribute::ExpireDelete) {
-                msg = i18np("Removed 1 old message from folder %2.",
-                            "Removed %1 old messages from folder %2.",
-                            mRemovedMsgs.count(),
-                            mSrcFolder.name());
+                msg = i18np("Removed 1 old message from folder %2.", "Removed %1 old messages from folder %2.", mRemovedMsgs.count(), mSrcFolder.name());
             } else {
                 msg = i18np("Moved 1 old message from folder %2 to folder %3.",
                             "Moved %1 old messages from folder %2 to folder %3.",
-                            mRemovedMsgs.count(), mSrcFolder.name(), mMoveToFolder.name());
+                            mRemovedMsgs.count(),
+                            mSrcFolder.name(),
+                            mMoveToFolder.name());
             }
             break;
 
         case Akonadi::Job::UserCanceled:
             if (expirationAttribute->expireAction() == MailCommon::ExpireCollectionAttribute::ExpireDelete) {
-                msg = i18n("Removing old messages from folder %1 was canceled.",
-                           mSrcFolder.name());
+                msg = i18n("Removing old messages from folder %1 was canceled.", mSrcFolder.name());
             } else {
-                msg = i18n("Moving old messages from folder %1 to folder %2 was "
-                           "canceled.",
-                           mSrcFolder.name(), mMoveToFolder.name());
+                msg = i18n(
+                    "Moving old messages from folder %1 to folder %2 was "
+                    "canceled.",
+                    mSrcFolder.name(),
+                    mMoveToFolder.name());
             }
             break;
 
-        default: //any other error
+        default: // any other error
             if (expirationAttribute->expireAction() == MailCommon::ExpireCollectionAttribute::ExpireDelete) {
-                msg = i18n("Removing old messages from folder %1 failed.",
-                           mSrcFolder.name());
+                msg = i18n("Removing old messages from folder %1 failed.", mSrcFolder.name());
             } else {
-                msg = i18n("Moving old messages from folder %1 to folder %2 failed.",
-                           mSrcFolder.name(), mMoveToFolder.name());
+                msg = i18n("Moving old messages from folder %1 to folder %2 failed.", mSrcFolder.name(), mMoveToFolder.name());
             }
             break;
         }
@@ -288,4 +265,3 @@ void ExpireJob::slotExpireDone(KJob *job)
     }
     deleteLater();
 }
-}
