@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "searchrule.h"
-#include "searchrule/searchrulenumerical.h"
-#include "searchrule/searchruledate.h"
-#include "searchrule/searchrulestring.h"
-#include "searchrule/searchrulestatus.h"
-#include "searchrule/searchruleencryption.h"
 #include "mailcommon_debug.h"
+#include "searchrule/searchruledate.h"
+#include "searchrule/searchruleencryption.h"
+#include "searchrule/searchrulenumerical.h"
+#include "searchrule/searchrulestatus.h"
+#include "searchrule/searchrulestring.h"
 
 #include <KMime/KMimeMessage>
 
@@ -30,24 +18,31 @@
 #include <QDataStream>
 
 #include <algorithm>
-#include <boost/bind.hpp>
 
 using namespace MailCommon;
 
-static const char *const funcConfigNames[] = {
-    "contains", "contains-not",
-    "equals", "not-equal",
-    "regexp", "not-regexp",
-    "greater", "less-or-equal", "less", "greater-or-equal",
-    "is-in-addressbook", "is-not-in-addressbook",
-    "is-in-category", "is-not-in-category",
-    "has-attachment", "has-no-attachment",
-    "start-with", "not-start-with",
-    "end-with", "not-end-with"
-};
+static const char *const funcConfigNames[] = {"contains",
+                                              "contains-not",
+                                              "equals",
+                                              "not-equal",
+                                              "regexp",
+                                              "not-regexp",
+                                              "greater",
+                                              "less-or-equal",
+                                              "less",
+                                              "greater-or-equal",
+                                              "is-in-addressbook",
+                                              "is-not-in-addressbook",
+                                              "is-in-category",
+                                              "is-not-in-category",
+                                              "has-attachment",
+                                              "has-no-attachment",
+                                              "start-with",
+                                              "not-start-with",
+                                              "end-with",
+                                              "not-end-with"};
 
-static const int numFuncConfigNames
-    = sizeof funcConfigNames / sizeof *funcConfigNames;
+static const int numFuncConfigNames = sizeof funcConfigNames / sizeof *funcConfigNames;
 
 //==================================================
 //
@@ -122,7 +117,7 @@ SearchRule::Ptr SearchRule::createInstanceFromConfig(const KConfigGroup &config,
     Function func2 = configValueToFunc(config.readEntry(func + cIdx, QString()).toLatin1().constData());
     const QString &contents2 = config.readEntry(contents + cIdx, QString());
 
-    if (field2 == "<To or Cc>") {   // backwards compat
+    if (field2 == "<To or Cc>") { // backwards compat
         return SearchRule::createInstance("<recipients>", func2, contents2);
     } else {
         return SearchRule::createInstance(field2, func2, contents2);
@@ -256,27 +251,27 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
 {
     QString contentStr = mContents;
     if (mField == "<size>") {
-        QString comparaison;
+        QString comparison;
         int offset = 0;
         switch (mFunction) {
         case FuncEquals:
-            comparaison = QLatin1Char('"') + i18n("size equals not supported") + QLatin1Char('"');
+            comparison = QLatin1Char('"') + i18n("size equals not supported") + QLatin1Char('"');
             break;
         case FuncNotEqual:
-            comparaison = QLatin1Char('"') + i18n("size not equals not supported") + QLatin1Char('"');
+            comparison = QLatin1Char('"') + i18n("size not equals not supported") + QLatin1Char('"');
             break;
         case FuncIsGreater:
-            comparaison = QStringLiteral(":over");
+            comparison = QStringLiteral(":over");
             break;
         case FuncIsLessOrEqual:
-            comparaison = QStringLiteral(":under");
+            comparison = QStringLiteral(":under");
             offset = 1;
             break;
         case FuncIsLess:
-            comparaison = QStringLiteral(":under");
+            comparison = QStringLiteral(":under");
             break;
         case FuncIsGreaterOrEqual:
-            comparaison = QStringLiteral(":over");
+            comparison = QStringLiteral(":over");
             offset = -1;
             break;
         case FuncIsInAddressbook:
@@ -294,58 +289,59 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
         case FuncContainsNot:
         case FuncRegExp:
         case FuncNotRegExp:
-            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction))
+                + QLatin1Char('"');
             return;
         }
-        code += QStringLiteral("size %1 %2K").arg(comparaison).arg(QString::number(mContents.toInt() + offset));
+        code += QStringLiteral("size %1 %2K").arg(comparison).arg(QString::number(mContents.toInt() + offset));
     } else if (mField == "<status>") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<status> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "<any header>") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<any header> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "contents") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<contents> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "<age in days>") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<age in days> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "<date>") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<date> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "<recipients>") {
-        //TODO ?
+        // TODO ?
         code += QLatin1Char('"') + i18n("<recipients> not implemented/supported") + QLatin1Char('"');
     } else if (mField == "<tag>") {
         code += QLatin1Char('"') + i18n("<Tag> is not supported") + QLatin1Char('"');
     } else if (mField == "<message>") {
-        //TODO ?
+        // TODO ?
         code += i18n("<message> not implemented/supported");
     } else if (mField == "<body>") {
         if (!requireModules.contains(QLatin1String("body"))) {
             requireModules << QStringLiteral("body");
         }
-        QString comparaison;
+        QString comparison;
         bool negative = false;
         switch (mFunction) {
         case FuncNone:
             break;
         case FuncContains:
-            comparaison = QStringLiteral(":contains");
+            comparison = QStringLiteral(":contains");
             break;
         case FuncContainsNot:
             negative = true;
-            comparaison = QStringLiteral(":contains");
+            comparison = QStringLiteral(":contains");
             break;
         case FuncEquals:
-            comparaison = QStringLiteral(":is");
+            comparison = QStringLiteral(":is");
             break;
         case FuncNotEqual:
-            comparaison = QStringLiteral(":is");
+            comparison = QStringLiteral(":is");
             negative = true;
             break;
         case FuncRegExp:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
@@ -354,39 +350,39 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             negative = true;
             break;
         case FuncStartWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
             contentStr = QLatin1Char('^') + contentStr;
             break;
         case FuncNotStartWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = QLatin1Char('^') + contentStr;
             negative = true;
             break;
         case FuncEndWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = contentStr + QLatin1Char('$');
             break;
         case FuncNotEndWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = contentStr + QLatin1Char('$');
             negative = true;
             break;
@@ -400,32 +396,33 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
         case FuncIsNotInCategory:
         case FuncHasAttachment:
         case FuncHasNoAttachment:
-            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction))
+                + QLatin1Char('"');
             return;
         }
-        code += (negative ? QStringLiteral("not ") : QString()) + QStringLiteral("body :text %1 \"%2\"").arg(comparaison, contentStr);
+        code += (negative ? QStringLiteral("not ") : QString()) + QStringLiteral("body :text %1 \"%2\"").arg(comparison, contentStr);
     } else {
-        QString comparaison;
+        QString comparison;
         bool negative = false;
         switch (mFunction) {
         case FuncNone:
             break;
         case FuncContains:
-            comparaison = QStringLiteral(":contains");
+            comparison = QStringLiteral(":contains");
             break;
         case FuncContainsNot:
             negative = true;
-            comparaison = QStringLiteral(":contains");
+            comparison = QStringLiteral(":contains");
             break;
         case FuncEquals:
-            comparaison = QStringLiteral(":is");
+            comparison = QStringLiteral(":is");
             break;
         case FuncNotEqual:
-            comparaison = QStringLiteral(":is");
+            comparison = QStringLiteral(":is");
             negative = true;
             break;
         case FuncRegExp:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
@@ -434,39 +431,39 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             negative = true;
             break;
         case FuncStartWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
             contentStr = QLatin1Char('^') + contentStr;
             break;
         case FuncNotStartWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = QLatin1Char('^') + contentStr;
             negative = true;
             break;
         case FuncEndWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = contentStr + QLatin1Char('$');
             break;
         case FuncNotEndWith:
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             if (!requireModules.contains(QLatin1String("regex"))) {
                 requireModules << QStringLiteral("regex");
             }
-            comparaison = QStringLiteral(":regex");
+            comparison = QStringLiteral(":regex");
             contentStr = contentStr + QLatin1Char('$');
             negative = true;
             break;
@@ -481,10 +478,12 @@ void SearchRule::generateSieveScript(QStringList &requireModules, QString &code)
         case FuncIsNotInCategory:
         case FuncHasAttachment:
         case FuncHasNoAttachment:
-            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction))
+                + QLatin1Char('"');
             return;
         }
-        code += (negative ? QStringLiteral("not ") : QString()) + QStringLiteral("header %1 \"%2\" \"%3\"").arg(comparaison).arg(QLatin1String(mField)).arg(contentStr);
+        code += (negative ? QStringLiteral("not ") : QString())
+            + QStringLiteral("header %1 \"%2\" \"%3\"").arg(comparison).arg(QLatin1String(mField)).arg(contentStr);
     }
 }
 
@@ -552,14 +551,14 @@ Akonadi::SearchTerm::Condition SearchRule::akonadiComparator() const
 
     case SearchRule::FuncRegExp:
     case SearchRule::FuncNotRegExp:
-        //TODO is this sufficient?
+        // TODO is this sufficient?
         return Akonadi::SearchTerm::CondContains;
 
     case SearchRule::FuncStartWith:
     case SearchRule::FuncNotStartWith:
     case SearchRule::FuncEndWith:
     case SearchRule::FuncNotEndWith:
-        //TODO is this sufficient?
+        // TODO is this sufficient?
         return Akonadi::SearchTerm::CondContains;
     default:
         qCDebug(MAILCOMMON_LOG) << "Unhandled function type: " << function();
@@ -587,7 +586,7 @@ bool SearchRule::isNegated() const
     return negate;
 }
 
-QDataStream &SearchRule::operator >>(QDataStream &s) const
+QDataStream &SearchRule::operator>>(QDataStream &s) const
 {
     s << mField << functionToString(mFunction) << mContents;
     return s;
