@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "searchrulenumerical.h"
@@ -21,10 +9,10 @@
 #include "filter/filterlog.h"
 using MailCommon::FilterLog;
 
-#include <QDateTime>
 #include <KMime/KMimeMessage>
+#include <QDateTime>
 
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include <algorithm>
 
@@ -49,7 +37,7 @@ bool SearchRuleNumerical::matches(const Akonadi::Item &item) const
         return false;
     }
 
-    const KMime::Message::Ptr msg = item.payload<KMime::Message::Ptr>();
+    const auto msg = item.payload<KMime::Message::Ptr>();
 
     QString msgContents;
     qint64 numericalMsgContents = 0;
@@ -69,8 +57,7 @@ bool SearchRuleNumerical::matches(const Akonadi::Item &item) const
     }
     bool rc = matchesInternal(numericalValue, numericalMsgContents, msgContents);
     if (FilterLog::instance()->isLogging()) {
-        QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>")
-                       : QStringLiteral("<font color=#FF0000>0 = </font>"));
+        QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>") : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msg += FilterLog::recode(asString());
         msg += QLatin1String(" ( <i>") + QString::number(numericalMsgContents) + QLatin1String("</i> )");
         FilterLog::instance()->add(msg, FilterLog::RuleResult);
@@ -99,16 +86,10 @@ bool SearchRuleNumerical::matchesInternal(long numericalValue, long numericalMsg
         return !msgContents.contains(contents(), Qt::CaseInsensitive);
 
     case SearchRule::FuncRegExp:
-    {
-        QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return regexp.indexIn(msgContents) >= 0;
-    }
+        return msgContents.contains(QRegularExpression(contents(), QRegularExpression::CaseInsensitiveOption));
 
     case SearchRule::FuncNotRegExp:
-    {
-        QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return regexp.indexIn(msgContents) < 0;
-    }
+        return !msgContents.contains(QRegularExpression(contents(), QRegularExpression::CaseInsensitiveOption));
 
     case FuncIsGreater:
         return numericalMsgContents > numericalValue;
@@ -122,14 +103,13 @@ bool SearchRuleNumerical::matchesInternal(long numericalValue, long numericalMsg
     case FuncIsGreaterOrEqual:
         return numericalMsgContents >= numericalValue;
 
-    case FuncIsInAddressbook:  // since email-addresses are not numerical, I settle for false here
+    case FuncIsInAddressbook: // since email-addresses are not numerical, I settle for false here
         return false;
 
     case FuncIsNotInAddressbook:
         return false;
 
-    default:
-        ;
+    default:;
     }
 
     return false;
