@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SEARCHRULENUMERICAL_H
-#define SEARCHRULENUMERICAL_H
+#pragma once
 
 #include "searchpattern.h"
-#include <AkonadiCore/Item>
-namespace MailCommon {
+#include <Akonadi/Item>
+namespace MailCommon
+{
 /**
  * @short This class represents a search pattern rule operating on numerical values.
  *
@@ -72,4 +60,3 @@ public:
     QString informationAboutNotValidRules() const override;
 };
 }
-#endif // SEARCHRULENUMERICAL_H
