@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "searchrulestring.h"
@@ -22,7 +10,7 @@ using MailCommon::FilterLog;
 
 #include <Akonadi/Contact/ContactSearchJob>
 
-#include <AkonadiCore/SearchQuery>
+#include <Akonadi/SearchQuery>
 
 #include <KMime/KMimeMessage>
 
@@ -30,10 +18,9 @@ using MailCommon::FilterLog;
 
 #include <KLocalizedString>
 
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include <algorithm>
-#include <boost/bind.hpp>
 
 using namespace MailCommon;
 SearchRuleString::SearchRuleString(const QByteArray &field, Function func, const QString &contents)
@@ -72,23 +59,14 @@ SearchRule::RequiredPart SearchRuleString::requiredPart() const
 {
     const QByteArray f = field();
     SearchRule::RequiredPart part = Header;
-    if (qstricmp(f.constData(), "<recipients>") == 0
-        || qstricmp(f.constData(), "<status>") == 0
-        || qstricmp(f.constData(), "<tag>") == 0
-        || qstricmp(f.constData(), "subject") == 0
-        || qstricmp(f.constData(), "from") == 0
-        || qstricmp(f.constData(), "sender") == 0
-        || qstricmp(f.constData(), "reply-to") == 0
-        || qstricmp(f.constData(), "to") == 0
-        || qstricmp(f.constData(), "cc") == 0
-        || qstricmp(f.constData(), "bcc") == 0
-        || qstricmp(f.constData(), "in-reply-to") == 0
-        || qstricmp(f.constData(), "message-id") == 0
+    if (qstricmp(f.constData(), "<recipients>") == 0 || qstricmp(f.constData(), "<status>") == 0 || qstricmp(f.constData(), "<tag>") == 0
+        || qstricmp(f.constData(), "subject") == 0 || qstricmp(f.constData(), "from") == 0 || qstricmp(f.constData(), "sender") == 0
+        || qstricmp(f.constData(), "reply-to") == 0 || qstricmp(f.constData(), "to") == 0 || qstricmp(f.constData(), "cc") == 0
+        || qstricmp(f.constData(), "bcc") == 0 || qstricmp(f.constData(), "in-reply-to") == 0 || qstricmp(f.constData(), "message-id") == 0
         || qstricmp(f.constData(), "references") == 0) {
         // these fields are directly provided by KMime::Message, no need to fetch the whole Header part
         part = Envelope;
-    } else if (qstricmp(f.constData(), "<message>") == 0
-               || qstricmp(f.constData(), "<body>") == 0) {
+    } else if (qstricmp(f.constData(), "<message>") == 0 || qstricmp(f.constData(), "<body>") == 0) {
         part = CompleteMessage;
     }
 
@@ -104,7 +82,7 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
         return false;
     }
 
-    const KMime::Message::Ptr msg = item.payload<KMime::Message::Ptr>();
+    const auto msg = item.payload<KMime::Message::Ptr>();
     Q_ASSERT(msg.data());
 
     if (!msg->hasHeader("From")) {
@@ -132,16 +110,14 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
         if (function() == FuncEquals || function() == FuncNotEqual) {
             // do we need to treat this case specially? Ie.: What shall
             // "equality" mean for recipients.
-            return
-                matchesInternal(msg->to()->asUnicodeString())
-                || matchesInternal(msg->cc()->asUnicodeString())
+            return matchesInternal(msg->to()->asUnicodeString()) || matchesInternal(msg->cc()->asUnicodeString())
                 || matchesInternal(msg->bcc()->asUnicodeString());
         }
         msgContents = msg->to()->asUnicodeString();
         msgContents += QLatin1String(", ") + msg->cc()->asUnicodeString();
         msgContents += QLatin1String(", ") + msg->bcc()->asUnicodeString();
     } else if (qstricmp(field().constData(), "<tag>") == 0) {
-        //port?
+        // port?
         //     const Nepomuk2::Resource res( item.url() );
         //     foreach ( const Nepomuk2::Tag &tag, res.tags() ) {
         //       msgContents += tag.label();
@@ -156,8 +132,7 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
         }
     }
 
-    if (function() == FuncIsInAddressbook
-        || function() == FuncIsNotInAddressbook) {
+    if (function() == FuncIsInAddressbook || function() == FuncIsNotInAddressbook) {
         // I think only the "from"-field makes sense.
         msgContents.clear();
         if (auto hrd = msg->headerByType(field().constData())) {
@@ -270,16 +245,10 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return !msgContents.contains(contents(), Qt::CaseInsensitive);
 
     case SearchRule::FuncRegExp:
-    {
-        QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return regexp.indexIn(msgContents) >= 0;
-    }
+        return msgContents.contains(QRegularExpression(contents(), QRegularExpression::CaseInsensitiveOption));
 
     case SearchRule::FuncNotRegExp:
-    {
-        QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return regexp.indexIn(msgContents) < 0;
-    }
+        return !msgContents.contains(QRegularExpression(contents(), QRegularExpression::CaseInsensitiveOption));
 
     case SearchRule::FuncStartWith:
         return msgContents.startsWith(contents());
@@ -305,14 +274,13 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
     case FuncIsGreaterOrEqual:
         return QString::compare(msgContents.toLower(), contents().toLower()) >= 0;
 
-    case FuncIsInAddressbook:
-    {
+    case FuncIsInAddressbook: {
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
         QStringList::ConstIterator end(addressList.constEnd());
         for (QStringList::ConstIterator it = addressList.constBegin(); (it != end); ++it) {
             const QString email(KEmailAddress::extractEmailAddress(*it).toLower());
             if (!email.isEmpty()) {
-                Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+                auto job = new Akonadi::ContactSearchJob();
                 job->setLimit(1);
                 job->setQuery(Akonadi::ContactSearchJob::Email, email);
                 job->exec();
@@ -325,15 +293,14 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsNotInAddressbook:
-    {
+    case FuncIsNotInAddressbook: {
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
         QStringList::ConstIterator end(addressList.constEnd());
 
         for (QStringList::ConstIterator it = addressList.constBegin(); (it != end); ++it) {
             const QString email(KEmailAddress::extractEmailAddress(*it).toLower());
             if (!email.isEmpty()) {
-                Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+                auto job = new Akonadi::ContactSearchJob();
                 job->setLimit(1);
                 job->setQuery(Akonadi::ContactSearchJob::Email, email);
                 job->exec();
@@ -346,8 +313,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsInCategory:
-    {
+    case FuncIsInCategory: {
         QString category = contents();
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
 
@@ -355,7 +321,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         for (QStringList::ConstIterator it = addressList.constBegin(); it != end; ++it) {
             const QString email(KEmailAddress::extractEmailAddress(*it).toLower());
             if (!email.isEmpty()) {
-                Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+                auto job = new Akonadi::ContactSearchJob();
                 job->setQuery(Akonadi::ContactSearchJob::Email, email);
                 job->exec();
 
@@ -371,8 +337,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsNotInCategory:
-    {
+    case FuncIsNotInCategory: {
         QString category = contents();
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
 
@@ -380,7 +345,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         for (QStringList::ConstIterator it = addressList.constBegin(); it != end; ++it) {
             const QString email(KEmailAddress::extractEmailAddress(*it).toLower());
             if (!email.isEmpty()) {
-                Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+                auto job = new Akonadi::ContactSearchJob();
                 job->setQuery(Akonadi::ContactSearchJob::Email, email);
                 job->exec();
 
@@ -395,8 +360,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         }
         return true;
     }
-    default:
-        ;
+    default:;
     }
 
     return false;
