@@ -1,27 +1,15 @@
 /*
-  Copyright (c) 2017  Daniel Vrátil <dvratil@kde.org>
+  SPDX-FileCopyrightText: 2017 Daniel Vrátil <dvratil@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SEARCH_ENCRYPTIONWIDGETHANDLER_H_
-#define MAILCOMMON_SEARCH_ENCRYPTIONWIDGETHANDLER_H_
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class EncryptionWidgetHandler : public RuleWidgetHandler
 {
 public:
@@ -40,4 +28,3 @@ public:
 };
 }
 
-#endif
