@@ -1,29 +1,17 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagerulewidgethandler.h"
 #include "search/searchpattern.h"
 
-#include <KLocalizedString>
 #include <KLineEdit>
-#include <QStackedWidget>
-#include <QLabel>
+#include <KLocalizedString>
 #include <QComboBox>
+#include <QLabel>
+#include <QStackedWidget>
 
 using namespace MailCommon;
 
@@ -33,26 +21,24 @@ static const struct {
     SearchRule::Function id;
     const char *displayName;
 } MessageFunctions[] = {
-    { SearchRule::FuncContains, I18N_NOOP("contains")          },
-    { SearchRule::FuncContainsNot, I18N_NOOP("does not contain")  },
-    { SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.") },
-    { SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.") },
-    { SearchRule::FuncHasAttachment, I18N_NOOP("has an attachment") },
-    { SearchRule::FuncHasNoAttachment, I18N_NOOP("has no attachment") },
+    {SearchRule::FuncContains, I18N_NOOP("contains")},
+    {SearchRule::FuncContainsNot, I18N_NOOP("does not contain")},
+    {SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.")},
+    {SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.")},
+    {SearchRule::FuncHasAttachment, I18N_NOOP("has an attachment")},
+    {SearchRule::FuncHasNoAttachment, I18N_NOOP("has no attachment")},
 };
-static const int MessageFunctionCount
-    = sizeof(MessageFunctions) / sizeof(*MessageFunctions);
+static const int MessageFunctionCount = sizeof(MessageFunctions) / sizeof(*MessageFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *MessageRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
+QWidget *MessageRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
     if (number != 0) {
         return nullptr;
     }
 
-    auto *funcCombo = new QComboBox(functionStack);
+    auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("messageRuleFuncCombo"));
     for (int i = 0; i < MessageFunctionCount; ++i) {
@@ -70,7 +56,7 @@ QWidget *MessageRuleWidgetHandler::createFunctionWidget(
 QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
     if (number == 0) {
-        KLineEdit *lineEdit = new KLineEdit(valueStack);
+        auto lineEdit = new KLineEdit(valueStack);
         lineEdit->setClearButtonEnabled(true);
         lineEdit->setTrapReturnKey(true);
 
@@ -82,7 +68,7 @@ QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 
     // blank QLabel to hide value widget for has-attachment rule
     if (number == 1) {
-        QLabel *label = new QLabel(valueStack);
+        auto label = new QLabel(valueStack);
         label->setObjectName(QStringLiteral("textRuleValueHider"));
         label->setBuddy(valueStack);
         return label;
@@ -93,8 +79,7 @@ QWidget *MessageRuleWidgetHandler::createValueWidget(int number, QStackedWidget
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function MessageRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function MessageRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("messageRuleFuncCombo"));
 
@@ -186,7 +171,7 @@ void MessageRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidg
     }
 
     // reset the value widget
-    KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+    auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
     if (lineEdit) {
         lineEdit->blockSignals(true);
@@ -234,12 +219,11 @@ bool MessageRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         functionStack->setCurrentWidget(funcCombo);
     }
 
-    if (func == SearchRule::FuncHasAttachment
-        || func == SearchRule::FuncHasNoAttachment) {
-        QWidget *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
+    if (func == SearchRule::FuncHasAttachment || func == SearchRule::FuncHasNoAttachment) {
+        auto *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
         valueStack->setCurrentWidget(w);
     } else {
-        KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             lineEdit->blockSignals(true);
@@ -266,12 +250,11 @@ bool MessageRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *f
 
     // raise the correct value widget
     SearchRule::Function func = currentFunction(functionStack);
-    if (func == SearchRule::FuncHasAttachment
-        || func == SearchRule::FuncHasNoAttachment) {
-        QWidget *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
+    if (func == SearchRule::FuncHasAttachment || func == SearchRule::FuncHasNoAttachment) {
+        auto *w = valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider"));
         valueStack->setCurrentWidget(w);
     } else {
-        KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             valueStack->setCurrentWidget(lineEdit);
