@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "numericdoublerulewidgethandler.h"
@@ -21,28 +9,24 @@
 
 #include <KLocalizedString>
 
+#include <QComboBox>
 #include <QDoubleSpinBox>
 #include <QStackedWidget>
-#include <QComboBox>
 
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
     const char *displayName;
-} NumericFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is equal to")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")      },
-    { SearchRule::FuncIsGreater, I18N_NOOP("is greater than")     },
-    { SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to") },
-    { SearchRule::FuncIsLess, I18N_NOOP("is less than")        },
-    { SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to") }
-};
-static const int NumericFunctionCount
-    = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
+} NumericDoubleFunctions[] = {{SearchRule::FuncEquals, I18N_NOOP("is equal to")},
+                              {SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")},
+                              {SearchRule::FuncIsGreater, I18N_NOOP("is greater than")},
+                              {SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to")},
+                              {SearchRule::FuncIsLess, I18N_NOOP("is less than")},
+                              {SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to")}};
+static const int NumericDoubleFunctionCount = sizeof(NumericDoubleFunctions) / sizeof(*NumericDoubleFunctions);
 
-QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
@@ -51,12 +35,11 @@ QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(
     auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("numericDoubleRuleFuncCombo"));
-    for (int i = 0; i < NumericFunctionCount; ++i) {
-        funcCombo->addItem(i18n(NumericFunctions[i].displayName));
+    for (int i = 0; i < NumericDoubleFunctionCount; ++i) {
+        funcCombo->addItem(i18n(NumericDoubleFunctions[i].displayName));
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -68,22 +51,20 @@ QWidget *NumericDoubleRuleWidgetHandler::createValueWidget(int number, QStackedW
         return nullptr;
     }
 
-    QDoubleSpinBox *numInput = new QDoubleSpinBox(valueStack);
+    auto numInput = new QDoubleSpinBox(valueStack);
     numInput->setObjectName(QStringLiteral("QDoubleSpinBox"));
-    QObject::connect(numInput, SIGNAL(valueChanged(double)),
-                     receiver, SLOT(slotValueChanged()));
+    QObject::connect(numInput, SIGNAL(valueChanged(double)), receiver, SLOT(slotValueChanged()));
     return numInput;
 }
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function NumericDoubleRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function NumericDoubleRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericDoubleRuleFuncCombo"));
 
     if (funcCombo && funcCombo->currentIndex() >= 0) {
-        return NumericFunctions[funcCombo->currentIndex()].id;
+        return NumericDoubleFunctions[funcCombo->currentIndex()].id;
     }
 
     return SearchRule::FuncNone;
@@ -156,7 +137,7 @@ void NumericDoubleRuleWidgetHandler::reset(QStackedWidget *functionStack, QStack
     }
 
     // reset the value widget
-    QDoubleSpinBox *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
+    auto *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
 
     if (numInput) {
         numInput->blockSignals(true);
@@ -179,7 +160,10 @@ void initDoubleNumInput(QDoubleSpinBox *numInput, const QByteArray &field)
 
 //---------------------------------------------------------------------------
 
-bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool /*isBalooSearch*/) const
+bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack,
+                                             QStackedWidget *valueStack,
+                                             const SearchRule::Ptr rule,
+                                             bool /*isBalooSearch*/) const
 {
     if (!rule || !handlesField(rule->field())) {
         reset(functionStack, valueStack);
@@ -189,8 +173,8 @@ bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QSta
     // set the function
     const SearchRule::Function func = rule->function();
     int funcIndex = 0;
-    for (; funcIndex < NumericFunctionCount; ++funcIndex) {
-        if (func == NumericFunctions[funcIndex].id) {
+    for (; funcIndex < NumericDoubleFunctionCount; ++funcIndex) {
+        if (func == NumericDoubleFunctions[funcIndex].id) {
             break;
         }
     }
@@ -199,7 +183,7 @@ bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QSta
 
     if (funcCombo) {
         funcCombo->blockSignals(true);
-        if (funcIndex < NumericFunctionCount) {
+        if (funcIndex < NumericDoubleFunctionCount) {
             funcCombo->setCurrentIndex(funcIndex);
         } else {
             funcCombo->setCurrentIndex(0);
@@ -215,7 +199,7 @@ bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QSta
         value = 0;
     }
 
-    QDoubleSpinBox *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
+    auto *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
 
     if (numInput) {
         initDoubleNumInput(numInput, rule->field());
@@ -239,7 +223,7 @@ bool NumericDoubleRuleWidgetHandler::update(const QByteArray &field, QStackedWid
     functionStack->setCurrentWidget(functionStack->findChild<QWidget *>(QStringLiteral("numericDoubleRuleFuncCombo")));
 
     // raise the correct value widget
-    QDoubleSpinBox *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
+    auto *numInput = valueStack->findChild<QDoubleSpinBox *>(QStringLiteral("QDoubleSpinBox"));
 
     if (numInput) {
         initDoubleNumInput(numInput, field);
