@@ -1,50 +1,34 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "numericrulewidgethandler.h"
 #include "search/searchpattern.h"
 
-#include <KPluralHandlingSpinBox>
 #include <KLocalizedString>
+#include <KPluralHandlingSpinBox>
 
-#include <QStackedWidget>
 #include <QComboBox>
+#include <QStackedWidget>
 
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
     const char *displayName;
-} NumericFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is equal to")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")      },
-    { SearchRule::FuncIsGreater, I18N_NOOP("is greater than")     },
-    { SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to") },
-    { SearchRule::FuncIsLess, I18N_NOOP("is less than")        },
-    { SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to") }
-};
-static const int NumericFunctionCount
-    = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
+} NumericFunctions[] = {{SearchRule::FuncEquals, I18N_NOOP("is equal to")},
+                        {SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")},
+                        {SearchRule::FuncIsGreater, I18N_NOOP("is greater than")},
+                        {SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to")},
+                        {SearchRule::FuncIsLess, I18N_NOOP("is less than")},
+                        {SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to")}};
+static const int NumericFunctionCount = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *NumericRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *NumericRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
@@ -57,8 +41,7 @@ QWidget *NumericRuleWidgetHandler::createFunctionWidget(
         funcCombo->addItem(i18n(NumericFunctions[i].displayName));
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -70,17 +53,15 @@ QWidget *NumericRuleWidgetHandler::createValueWidget(int number, QStackedWidget
         return nullptr;
     }
 
-    KPluralHandlingSpinBox *numInput = new KPluralHandlingSpinBox(valueStack);
+    auto numInput = new KPluralHandlingSpinBox(valueStack);
     numInput->setObjectName(QStringLiteral("KPluralHandlingSpinBox"));
-    QObject::connect(numInput, SIGNAL(valueChanged(int)),
-                     receiver, SLOT(slotValueChanged()));
+    QObject::connect(numInput, SIGNAL(valueChanged(int)), receiver, SLOT(slotValueChanged()));
     return numInput;
 }
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function NumericRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function NumericRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericRuleFuncCombo"));
 
@@ -158,7 +139,7 @@ void NumericRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidg
     }
 
     // reset the value widget
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         numInput->blockSignals(true);
@@ -215,7 +196,7 @@ bool NumericRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWi
         value = 0;
     }
 
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         initNumInput(numInput, rule->field());
@@ -239,7 +220,7 @@ bool NumericRuleWidgetHandler::update(const QByteArray &field, QStackedWidget *f
     functionStack->setCurrentWidget(functionStack->findChild<QWidget *>(QStringLiteral("numericRuleFuncCombo")));
 
     // raise the correct value widget
-    KPluralHandlingSpinBox *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
+    auto *numInput = valueStack->findChild<KPluralHandlingSpinBox *>(QStringLiteral("KPluralHandlingSpinBox"));
 
     if (numInput) {
         initNumInput(numInput, field);
