@@ -1,13 +1,14 @@
-#ifndef NUMERICRULEWIDGETHANDLER_H
-#define NUMERICRULEWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class NumericRuleWidgetHandler : public MailCommon::RuleWidgetHandler
 {
 public:
-    NumericRuleWidgetHandler() : MailCommon::RuleWidgetHandler()
+    NumericRuleWidgetHandler()
+        : MailCommon::RuleWidgetHandler()
     {
     }
 
@@ -38,4 +39,3 @@ private:
     QString currentValue(const QStackedWidget *valueStack) const;
 };
 }
-#endif // NUMERICRULEWIDGETHANDLER_H
