@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "textrulerwidgethandler.h"
@@ -33,40 +21,35 @@ using namespace MailCommon;
 static const struct {
     SearchRule::Function id;
     const char *displayName;
-} TextFunctions[] = {
-    { SearchRule::FuncContains, I18N_NOOP("contains")          },
-    { SearchRule::FuncContainsNot, I18N_NOOP("does not contain")   },
-    { SearchRule::FuncEquals, I18N_NOOP("equals")            },
-    { SearchRule::FuncNotEqual, I18N_NOOP("does not equal")     },
-    { SearchRule::FuncStartWith, I18N_NOOP("starts with")         },
-    { SearchRule::FuncNotStartWith, I18N_NOOP("does not start with")},
-    { SearchRule::FuncEndWith, I18N_NOOP("ends with")           },
-    { SearchRule::FuncNotEndWith, I18N_NOOP("does not end with")  },
+} TextFunctions[] = {{SearchRule::FuncContains, I18N_NOOP("contains")},
+                     {SearchRule::FuncContainsNot, I18N_NOOP("does not contain")},
+                     {SearchRule::FuncEquals, I18N_NOOP("equals")},
+                     {SearchRule::FuncNotEqual, I18N_NOOP("does not equal")},
+                     {SearchRule::FuncStartWith, I18N_NOOP("starts with")},
+                     {SearchRule::FuncNotStartWith, I18N_NOOP("does not start with")},
+                     {SearchRule::FuncEndWith, I18N_NOOP("ends with")},
+                     {SearchRule::FuncNotEndWith, I18N_NOOP("does not end with")},
 
-    { SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.") },
-    { SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.") }
-};
-static const int TextFunctionCount
-    = sizeof(TextFunctions) / sizeof(*TextFunctions);
+                     {SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.")},
+                     {SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.")}};
+static const int TextFunctionCount = sizeof(TextFunctions) / sizeof(*TextFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *TextRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *TextRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
     }
 
-    auto *funcCombo = new QComboBox(functionStack);
+    auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("textRuleFuncCombo"));
     for (int i = 0; i < TextFunctionCount; ++i) {
         funcCombo->addItem(i18n(TextFunctions[i].displayName));
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -75,20 +58,18 @@ QWidget *TextRuleWidgetHandler::createFunctionWidget(
 QWidget *TextRuleWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
     if (number == 0) {
-        KLineEdit *lineEdit = new KLineEdit(valueStack);
+        auto lineEdit = new KLineEdit(valueStack);
         lineEdit->setClearButtonEnabled(true);
         lineEdit->setTrapReturnKey(true);
         lineEdit->setObjectName(QStringLiteral("regExpLineEdit"));
-        QObject::connect(lineEdit, SIGNAL(textChanged(QString)),
-                         receiver, SLOT(slotValueChanged()));
-        QObject::connect(lineEdit, SIGNAL(returnPressed()),
-                         receiver, SLOT(slotReturnPressed()));
+        QObject::connect(lineEdit, SIGNAL(textChanged(QString)), receiver, SLOT(slotValueChanged()));
+        QObject::connect(lineEdit, SIGNAL(returnPressed()), receiver, SLOT(slotReturnPressed()));
         return lineEdit;
     }
 
     // blank QLabel to hide value widget for in-address-book rule
     if (number == 1) {
-        QLabel *label = new QLabel(valueStack);
+        auto label = new QLabel(valueStack);
         label->setObjectName(QStringLiteral("textRuleValueHider"));
         label->setBuddy(valueStack);
         return label;
@@ -98,8 +79,7 @@ QWidget *TextRuleWidgetHandler::createValueWidget(int number, QStackedWidget *va
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function TextRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function TextRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("textRuleFuncCombo"));
 
@@ -121,7 +101,7 @@ SearchRule::Function TextRuleWidgetHandler::function(const QByteArray &, const Q
 
 QString TextRuleWidgetHandler::currentValue(const QStackedWidget *valueStack, SearchRule::Function) const
 {
-    //in other cases of func it is a lineedit
+    // in other cases of func it is a lineedit
     const KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
     if (lineEdit) {
@@ -169,7 +149,7 @@ void TextRuleWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidget
     }
 
     // reset the value widget
-    KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+    auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
     if (lineEdit) {
         lineEdit->blockSignals(true);
         lineEdit->clear();
@@ -209,8 +189,7 @@ bool TextRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidge
         funcCombo->blockSignals(false);
         functionStack->setCurrentWidget(funcCombo);
     }
-    KLineEdit *lineEdit
-        = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+    auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
     if (lineEdit) {
         lineEdit->blockSignals(true);
@@ -232,12 +211,10 @@ bool TextRuleWidgetHandler::update(const QByteArray &, QStackedWidget *functionS
 
     // raise the correct value widget
     SearchRule::Function func = currentFunction(functionStack);
-    if (func == SearchRule::FuncIsInAddressbook
-        || func == SearchRule::FuncIsNotInAddressbook) {
+    if (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook) {
         valueStack->setCurrentWidget(valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider")));
     } else {
-        KLineEdit *lineEdit
-            = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             valueStack->setCurrentWidget(lineEdit);
