@@ -1,23 +1,10 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author Tobias Koenig <tokoe@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "snippetsmanager.h"
@@ -25,24 +12,24 @@
 #include "snippetdialog.h"
 #include "snippetsmodel.h"
 #include "snippetvariabledialog.h"
-#include <KSharedConfig>
 #include <KActionCollection>
+#include <KSharedConfig>
 
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QIcon>
-#include <QTextEdit>
 
 #include <QAction>
-#include <QPointer>
 #include <QItemSelectionModel>
+#include <QPointer>
+#include <QRegularExpression>
 
 using namespace MailCommon;
 
-class Q_DECL_HIDDEN SnippetsManager::Private
+class Q_DECL_HIDDEN SnippetsManager::SnippetsManagerPrivate
 {
 public:
-    Private(SnippetsManager *qq, QWidget *parentWidget)
+    SnippetsManagerPrivate(SnippetsManager *qq, QWidget *parentWidget)
         : q(qq)
         , mParent(parentWidget)
     {
@@ -67,15 +54,30 @@ public:
 
     void slotAddNewDndSnippset(const QString &);
 
-    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
-    void initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void updateActionCollection(const QString &oldName,
+                                const QString &newName,
+                                const QKeySequence &keySequence,
+                                const QString &text,
+                                const QString &subject,
+                                const QString &to,
+                                const QString &cc,
+                                const QString &bcc,
+                                const QString &attachment);
+    void initializeAction(const QString &newName,
+                          const QKeySequence &keySequence,
+                          const QString &text,
+                          const QString &subject,
+                          const QString &to,
+                          const QString &cc,
+                          const QString &bcc,
+                          const QString &attachment);
     void initializeActionCollection();
 
     QString replaceVariables(const QString &text);
 
     void save();
 
-    SnippetsManager * const q = nullptr;
+    SnippetsManager *const q;
     SnippetsModel *mModel = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
     KActionCollection *mActionCollection = nullptr;
@@ -90,7 +92,7 @@ public:
     bool mDirty = false;
 };
 
-QModelIndex SnippetsManager::Private::currentGroupIndex() const
+QModelIndex SnippetsManager::SnippetsManagerPrivate::currentGroupIndex() const
 {
     if (mSelectionModel->selectedIndexes().isEmpty()) {
         return QModelIndex();
@@ -104,7 +106,7 @@ QModelIndex SnippetsManager::Private::currentGroupIndex() const
     }
 }
 
-void SnippetsManager::Private::selectionChanged()
+void SnippetsManager::SnippetsManagerPrivate::selectionChanged()
 {
     const bool itemSelected = !mSelectionModel->selectedIndexes().isEmpty();
 
@@ -133,12 +135,12 @@ void SnippetsManager::Private::selectionChanged()
     }
 }
 
-void SnippetsManager::Private::addSnippet()
+void SnippetsManager::SnippetsManagerPrivate::addSnippet()
 {
     createSnippet();
 }
 
-void SnippetsManager::Private::createSnippet(const QString &text)
+void SnippetsManager::SnippetsManagerPrivate::createSnippet(const QString &text)
 {
     const bool noGroupAvailable = (mModel->rowCount() == 0);
 
@@ -160,7 +162,11 @@ void SnippetsManager::Private::createSnippet(const QString &text)
     dlg->setGroupIndex(currentGroupIndex());
     dlg->setText(text);
 
-    if (dlg->exec()) {
+    q->connect(dlg, &SnippetDialog::rejected, q, [dlg]() {
+        delete dlg;
+    });
+
+    q->connect(dlg, &SnippetDialog::accepted, q, [dlg, this]() {
         const QModelIndex groupIndex = dlg->groupIndex();
 
         if (!mModel->insertRow(mModel->rowCount(groupIndex), groupIndex)) {
@@ -179,24 +185,33 @@ void SnippetsManager::Private::createSnippet(const QString &text)
         mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
         mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        Q_EMIT mModel->updateActionCollection(QString(), dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
+        Q_EMIT mModel->updateActionCollection(QString(),
+                                              dlg->name(),
+                                              dlg->keySequence(),
+                                              dlg->text(),
+                                              dlg->subject(),
+                                              dlg->to(),
+                                              dlg->cc(),
+                                              dlg->bcc(),
+                                              dlg->attachment());
         mDirty = true;
         save();
-    }
-    delete dlg;
+        delete dlg;
+    });
+    dlg->show();
 }
 
-void SnippetsManager::Private::slotAddNewDndSnippset(const QString &text)
+void SnippetsManager::SnippetsManagerPrivate::slotAddNewDndSnippset(const QString &text)
 {
     createSnippet(text);
 }
 
-void SnippetsManager::Private::dndDone()
+void SnippetsManager::SnippetsManagerPrivate::dndDone()
 {
     mDirty = true;
 }
 
-void SnippetsManager::Private::editSnippet()
+void SnippetsManager::SnippetsManagerPrivate::editSnippet()
 {
     QModelIndex index = mSelectionModel->selectedIndexes().first();
     if (!index.isValid() || index.data(SnippetsModel::IsGroupRole).toBool()) {
@@ -219,50 +234,61 @@ void SnippetsManager::Private::editSnippet()
     dlg->setCc(index.data(SnippetsModel::CcRole).toString());
     dlg->setBcc(index.data(SnippetsModel::BccRole).toString());
     dlg->setAttachment(index.data(SnippetsModel::AttachmentRole).toString());
-    dlg->setKeySequence(
-        QKeySequence::fromString(
-            index.data(SnippetsModel::KeySequenceRole).toString()));
+    dlg->setKeySequence(QKeySequence::fromString(index.data(SnippetsModel::KeySequenceRole).toString()));
+    q->connect(dlg, &SnippetDialog::rejected, q, [dlg]() {
+        delete dlg;
+    });
 
-    if (dlg->exec()) {
+    q->connect(dlg, &SnippetDialog::accepted, q, [dlg, this, oldGroupIndex, index, oldSnippetName]() {
         const QModelIndex newGroupIndex = dlg->groupIndex();
-
+        QModelIndex oldIndex = index;
         if (oldGroupIndex != newGroupIndex) {
             mModel->removeRow(index.row(), oldGroupIndex);
             mModel->insertRow(mModel->rowCount(newGroupIndex), newGroupIndex);
 
-            index = mModel->index(mModel->rowCount(newGroupIndex) - 1, 0, newGroupIndex);
+            oldIndex = mModel->index(mModel->rowCount(newGroupIndex) - 1, 0, newGroupIndex);
         }
 
-        mModel->setData(index, dlg->name(), SnippetsModel::NameRole);
-        mModel->setData(index, dlg->text(), SnippetsModel::TextRole);
-        mModel->setData(index, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
-        mModel->setData(index, dlg->keyword(), SnippetsModel::KeywordRole);
-        mModel->setData(index, dlg->subject(), SnippetsModel::SubjectRole);
-        mModel->setData(index, dlg->to(), SnippetsModel::ToRole);
-        mModel->setData(index, dlg->cc(), SnippetsModel::CcRole);
-        mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
-        mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
+        mModel->setData(oldIndex, dlg->name(), SnippetsModel::NameRole);
+        mModel->setData(oldIndex, dlg->text(), SnippetsModel::TextRole);
+        mModel->setData(oldIndex, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
+        mModel->setData(oldIndex, dlg->keyword(), SnippetsModel::KeywordRole);
+        mModel->setData(oldIndex, dlg->subject(), SnippetsModel::SubjectRole);
+        mModel->setData(oldIndex, dlg->to(), SnippetsModel::ToRole);
+        mModel->setData(oldIndex, dlg->cc(), SnippetsModel::CcRole);
+        mModel->setData(oldIndex, dlg->bcc(), SnippetsModel::BccRole);
+        mModel->setData(oldIndex, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        Q_EMIT mModel->updateActionCollection(oldSnippetName, dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
+        Q_EMIT mModel->updateActionCollection(oldSnippetName,
+                                              dlg->name(),
+                                              dlg->keySequence(),
+                                              dlg->text(),
+                                              dlg->subject(),
+                                              dlg->to(),
+                                              dlg->cc(),
+                                              dlg->bcc(),
+                                              dlg->attachment());
         mDirty = true;
         save();
-    }
-    delete dlg;
+        delete dlg;
+    });
+    dlg->show();
 }
 
-void SnippetsManager::Private::deleteSnippet()
+void SnippetsManager::SnippetsManagerPrivate::deleteSnippet()
 {
     const QModelIndex index = mSelectionModel->selectedIndexes().first();
 
     const QString snippetName = index.data(SnippetsModel::NameRole).toString();
 
-    if (KMessageBox::warningContinueCancel(
-            nullptr,
-            xi18nc("@info",
-                   "Do you really want to remove snippet \"%1\"?<nl/>"
-                   "<warning>There is no way to undo the removal.</warning>", snippetName),
-            QString(),
-            KStandardGuiItem::remove()) == KMessageBox::Cancel) {
+    if (KMessageBox::warningContinueCancel(nullptr,
+                                           xi18nc("@info",
+                                                  "Do you really want to remove snippet \"%1\"?<nl/>"
+                                                  "<warning>There is no way to undo the removal.</warning>",
+                                                  snippetName),
+                                           QString(),
+                                           KStandardGuiItem::remove())
+        == KMessageBox::Cancel) {
         return;
     }
 
@@ -273,7 +299,7 @@ void SnippetsManager::Private::deleteSnippet()
     save();
 }
 
-void SnippetsManager::Private::addSnippetGroup()
+void SnippetsManager::SnippetsManagerPrivate::addSnippetGroup()
 {
     QPointer<SnippetDialog> dlg = new SnippetDialog(mActionCollection, true, mParent);
     dlg->setWindowTitle(i18nc("@title:window", "Add Group"));
@@ -293,7 +319,7 @@ void SnippetsManager::Private::addSnippetGroup()
     delete dlg;
 }
 
-void SnippetsManager::Private::editSnippetGroup()
+void SnippetsManager::SnippetsManagerPrivate::editSnippetGroup()
 {
     const QModelIndex groupIndex = currentGroupIndex();
     if (!groupIndex.isValid() || !groupIndex.data(SnippetsModel::IsGroupRole).toBool()) {
@@ -318,7 +344,7 @@ void SnippetsManager::Private::editSnippetGroup()
     delete dlg;
 }
 
-void SnippetsManager::Private::deleteSnippetGroup()
+void SnippetsManager::SnippetsManagerPrivate::deleteSnippetGroup()
 {
     const QModelIndex groupIndex = currentGroupIndex();
     if (!groupIndex.isValid()) {
@@ -328,22 +354,22 @@ void SnippetsManager::Private::deleteSnippetGroup()
     const QString groupName = groupIndex.data(SnippetsModel::NameRole).toString();
 
     if (mModel->rowCount(groupIndex) > 0) {
-        if (KMessageBox::warningContinueCancel(
-                nullptr,
-                xi18nc("@info",
-                       "Do you really want to remove group \"%1\" along with all its snippets?<nl/>"
-                       "<warning>There is no way to undo the removal.</warning>", groupName),
-                QString(),
-                KStandardGuiItem::remove()) == KMessageBox::Cancel) {
+        if (KMessageBox::warningContinueCancel(nullptr,
+                                               xi18nc("@info",
+                                                      "Do you really want to remove group \"%1\" along with all its snippets?<nl/>"
+                                                      "<warning>There is no way to undo the removal.</warning>",
+                                                      groupName),
+                                               QString(),
+                                               KStandardGuiItem::remove())
+            == KMessageBox::Cancel) {
             return;
         }
     } else {
-        if (KMessageBox::warningContinueCancel(
-                nullptr,
-                i18nc("@info",
-                      "Do you really want to remove group \"%1\"?", groupName),
-                QString(),
-                KStandardGuiItem::remove()) == KMessageBox::Cancel) {
+        if (KMessageBox::warningContinueCancel(nullptr,
+                                               i18nc("@info", "Do you really want to remove group \"%1\"?", groupName),
+                                               QString(),
+                                               KStandardGuiItem::remove())
+            == KMessageBox::Cancel) {
             return;
         }
     }
@@ -353,7 +379,7 @@ void SnippetsManager::Private::deleteSnippetGroup()
     save();
 }
 
-void SnippetsManager::Private::insertSelectedSnippet()
+void SnippetsManager::SnippetsManagerPrivate::insertSelectedSnippet()
 {
     if (!mSelectionModel->hasSelection()) {
         return;
@@ -373,9 +399,9 @@ void SnippetsManager::Private::insertSelectedSnippet()
     Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
-void SnippetsManager::Private::insertActionSnippet()
+void SnippetsManager::SnippetsManagerPrivate::insertActionSnippet()
 {
-    QAction *action = qobject_cast<QAction *>(q->sender());
+    auto action = qobject_cast<QAction *>(q->sender());
     if (!action) {
         return;
     }
@@ -389,7 +415,7 @@ void SnippetsManager::Private::insertActionSnippet()
     Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
-void SnippetsManager::Private::initializeActionCollection()
+void SnippetsManager::SnippetsManagerPrivate::initializeActionCollection()
 {
     if (mActionCollection) {
         const QVector<SnippetsInfo> infos = mModel->snippetsInfo();
@@ -399,13 +425,19 @@ void SnippetsManager::Private::initializeActionCollection()
     }
 }
 
-void SnippetsManager::Private::initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
+void SnippetsManager::SnippetsManagerPrivate::initializeAction(const QString &newName,
+                                                               const QKeySequence &keySequence,
+                                                               const QString &text,
+                                                               const QString &subject,
+                                                               const QString &to,
+                                                               const QString &cc,
+                                                               const QString &bcc,
+                                                               const QString &attachment)
 {
     const QString actionName = i18nc("@action", "Snippet %1", newName);
     const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
 
-    QAction *action
-        = mActionCollection->addAction(normalizedName, q);
+    QAction *action = mActionCollection->addAction(normalizedName, q);
     connect(action, &QAction::triggered, q, [this]() {
         insertActionSnippet();
     });
@@ -419,7 +451,15 @@ void SnippetsManager::Private::initializeAction(const QString &newName, const QK
     mActionCollection->setDefaultShortcut(action, keySequence);
 }
 
-void SnippetsManager::Private::updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
+void SnippetsManager::SnippetsManagerPrivate::updateActionCollection(const QString &oldName,
+                                                                     const QString &newName,
+                                                                     const QKeySequence &keySequence,
+                                                                     const QString &text,
+                                                                     const QString &subject,
+                                                                     const QString &to,
+                                                                     const QString &cc,
+                                                                     const QString &bcc,
+                                                                     const QString &attachment)
 {
     // remove previous action in case that the name changed
     if (!oldName.isEmpty() && mActionCollection) {
@@ -437,7 +477,7 @@ void SnippetsManager::Private::updateActionCollection(const QString &oldName, co
     }
 }
 
-QString SnippetsManager::Private::replaceVariables(const QString &text)
+QString SnippetsManager::SnippetsManagerPrivate::replaceVariables(const QString &text)
 {
     QString result = text;
     QString variableName;
@@ -447,15 +487,15 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
     int iEnd = -1;
     QMap<QString, QString> tempLocalVariables(localVariables);
     do {
-        //find the next variable by this QRegExp
-        iFound = text.indexOf(QRegExp(QLatin1String("\\$[A-Za-z-_0-9\\s]*\\$")), iEnd + 1);
+        // find the next variable by this regex
+        iFound = text.indexOf(QRegularExpression(QStringLiteral("\\$[A-Za-z\\-_0-9\\s]*\\$")), iEnd + 1);
         if (iFound >= 0) {
             iEnd = text.indexOf(QLatin1Char('$'), iFound + 1) + 1;
 
             variableName = text.mid(iFound, iEnd - iFound);
 
-            if (variableName != QLatin1String("$$")) {      // if not double-delimiter
-                if (!localVariables.contains(variableName)) {      // and not already in map
+            if (variableName != QLatin1String("$$")) { // if not double-delimiter
+                if (!localVariables.contains(variableName)) { // and not already in map
                     QPointer<SnippetVariableDialog> dlg = new SnippetVariableDialog(variableName, &tempLocalVariables, mParent);
                     if (dlg->exec()) {
                         if (dlg->saveVariableIsChecked()) {
@@ -471,11 +511,11 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
                     variableValue = localVariables.value(variableName);
                 }
             } else {
-                variableValue = QLatin1Char('$'); //if double-delimiter -> replace by single character
+                variableValue = QLatin1Char('$'); // if double-delimiter -> replace by single character
             }
 
             result.replace(variableName, variableValue);
-            localVariables[ variableName ] = variableValue;
+            localVariables[variableName] = variableValue;
         }
     } while (iFound != -1);
     SnippetsModel::instance()->setSavedVariables(tempLocalVariables);
@@ -483,7 +523,7 @@ QString SnippetsManager::Private::replaceVariables(const QString &text)
     return result;
 }
 
-void SnippetsManager::Private::save()
+void SnippetsManager::SnippetsManagerPrivate::save()
 {
     if (!mDirty) {
         return;
@@ -495,12 +535,23 @@ void SnippetsManager::Private::save()
 
 SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *parent, QWidget *parentWidget)
     : QObject(parent)
-    , d(new Private(this, parentWidget))
+    , d(new SnippetsManagerPrivate(this, parentWidget))
 {
     d->mModel = SnippetsModel::instance();
-    connect(d->mModel, &SnippetsModel::updateActionCollection, this, [this](const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment) {
-        d->updateActionCollection(oldName, newName, keySequence, text, subject, to, cc, bcc, attachment);
-    });
+    connect(d->mModel,
+            &SnippetsModel::updateActionCollection,
+            this,
+            [this](const QString &oldName,
+                   const QString &newName,
+                   const QKeySequence &keySequence,
+                   const QString &text,
+                   const QString &subject,
+                   const QString &to,
+                   const QString &cc,
+                   const QString &bcc,
+                   const QString &attachment) {
+                d->updateActionCollection(oldName, newName, keySequence, text, subject, to, cc, bcc, attachment);
+            });
     d->mSelectionModel = new QItemSelectionModel(d->mModel);
     d->mActionCollection = actionCollection;
 
@@ -521,8 +572,7 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
     d->mInsertSnippetAction = new QAction(i18n("Insert Snippet"), this);
     d->mInsertSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("insert-text")));
 
-    connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged,
-            this, [this]() {
+    connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged, this, [this]() {
         d->selectionChanged();
     });
     connect(d->mModel, &SnippetsModel::dndDone, this, [this]() {
@@ -566,7 +616,6 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
 SnippetsManager::~SnippetsManager()
 {
     d->save();
-    delete d;
 }
 
 QAbstractItemModel *SnippetsManager::model() const
