@@ -1,33 +1,21 @@
 /*
- * Copyright (c) 2017  Daniel Vrátil <dvratil@kde.org>
+ * SPDX-FileCopyrightText: 2017 Daniel Vrátil <dvratil@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "cryptoutils.h"
 #include "mailcommon_debug.h"
 
-#include <QGpgME/Protocol>
 #include <QGpgME/DecryptJob>
+#include <QGpgME/Protocol>
 #include <QGpgME/VerifyOpaqueJob>
 
-#include <gpgme++/decryptionresult.h>
-#include <gpgme++/verificationresult.h>
 #include <gpgme++/context.h>
+#include <gpgme++/decryptionresult.h>
 #include <gpgme++/gpgmepp_version.h>
+#include <gpgme++/verificationresult.h>
 
 using namespace MailCommon;
 
@@ -61,9 +49,7 @@ bool CryptoUtils::isInlinePGP(const KMime::Content *part)
 bool CryptoUtils::isPGP(const KMime::Content *part, bool allowOctetStream)
 {
     const auto ct = static_cast<KMime::Headers::ContentType *>(part->headerByType("Content-Type"));
-    return ct && (ct->isSubtype("pgp-encrypted")
-                  || ct->isSubtype("encrypted")
-                  || (allowOctetStream && ct->isMimeType("application/octet-stream")));
+    return ct && (ct->isSubtype("pgp-encrypted") || ct->isSubtype("encrypted") || (allowOctetStream && ct->isMimeType("application/octet-stream")));
 }
 
 bool CryptoUtils::isSMIME(const KMime::Content *part)
@@ -170,9 +156,7 @@ void CryptoUtils::copyHeader(const KMime::Headers::Base *header, KMime::Message:
 
 bool CryptoUtils::isContentHeader(const KMime::Headers::Base *header)
 {
-    return header->is("Content-Type")
-           || header->is("Content-Transfer-Encoding")
-           || header->is("Content-Disposition");
+    return header->is("Content-Type") || header->is("Content-Transfer-Encoding") || header->is("Content-Disposition");
 }
 
 KMime::Message::Ptr CryptoUtils::assembleMessage(const KMime::Message::Ptr &orig, const KMime::Content *newContent)
@@ -182,10 +166,18 @@ KMime::Message::Ptr CryptoUtils::assembleMessage(const KMime::Message::Ptr &orig
     out->setBody(const_cast<KMime::Content *>(newContent)->encodedBody());
     out->parse();
 
+    // remove default explicit content headers added by KMime::Content::parse()
+    QVector<KMime::Headers::Base *> headers = out->headers();
+    for (const auto hdr : std::as_const(headers)) {
+        if (isContentHeader(hdr)) {
+            out->removeHeader(hdr->type());
+        }
+    }
+
     // Copy over headers from the original message, except for CT, CTE and CD
     // headers, we want to preserve those from the new content
-    QVector<KMime::Headers::Base *> headers = orig->headers();
-    for (const auto hdr : qAsConst(headers)) {
+    headers = orig->headers();
+    for (const auto hdr : std::as_const(headers)) {
         if (isContentHeader(hdr)) {
             continue;
         }
@@ -195,7 +187,7 @@ KMime::Message::Ptr CryptoUtils::assembleMessage(const KMime::Message::Ptr &orig
 
     // Overwrite some headers by those provided by the new content
     headers = newContent->headers();
-    for (const auto hdr : qAsConst(headers)) {
+    for (const auto hdr : std::as_const(headers)) {
         if (isContentHeader(hdr)) {
             copyHeader(hdr, out);
         }
