@@ -1,85 +1,52 @@
-/*******************************************************************************
-**
-** Filename   : util
-** Created on : 03 April, 2005
-** Copyright  : (c) 2005 Till Adam
-** Email      : <adam@kde.org>
-**
-*******************************************************************************/
+/*
+  SPDX-FileCopyrightText: 2005 Till Adam <adam@kde.org>
 
-/*******************************************************************************
-**
-**   This program is free software; you can redistribute it and/or modify
-**   it under the terms of the GNU General Public License as published by
-**   the Free Software Foundation; either version 2 of the License, or
-**   (at your option) any later version.
-**
-**   It is distributed in the hope that it will be useful, but
-**   WITHOUT ANY WARRANTY; without even the implied warranty of
-**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-**   General Public License for more details.
-**
-**   You should have received a copy of the GNU General Public License
-**   along with this program; if not, write to the Free Software
-**   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-**
-**   In addition, as a special exception, the copyright holders give
-**   permission to link the code of this program with any edition of
-**   the Qt library by Trolltech AS, Norway (or with modified versions
-**   of Qt that use the same license as Qt), and distribute linked
-**   combinations including the two.  You must obey the GNU General
-**   Public License in all respects for all of the code used other than
-**   Qt.  If you modify this file, you may extend this exception to
-**   your version of the file, but you are not obligated to do so.  If
-**   you do not wish to do so, delete this exception statement from
-**   your version.
-**
-*******************************************************************************/
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mailutil.h"
 #include "mailutil_p.h"
 
-#include "mailcommon_debug.h"
 #include "calendarinterface.h"
-#include "job/expirejob.h"
-#include "folder/foldersettings.h"
-#include "pop3settings.h"
-#include "kernel/mailkernel.h"
 #include "filter/dialog/filteractionmissingfolderdialog.h"
+#include "folder/foldersettings.h"
+#include "job/expirejob.h"
+#include "kernel/mailkernel.h"
+#include "mailcommon_debug.h"
+#include "pop3settings.h"
 
-#include "mailimporter/filterbalsa.h"
-#include "mailimporter/filterevolution.h"
-#include "mailimporter/filterevolution_v2.h"
-#include "mailimporter/filterevolution_v3.h"
-#include "mailimporter/filterclawsmail.h"
-#include "mailimporter/filtersylpheed.h"
-#include "mailimporter/filterthunderbird.h"
-#include "mailimporter/filteropera.h"
-#include "mailimporter/filtericedove.h"
-#include "mailimporter/othermailerutil.h"
+#include <MailImporter/FilterBalsa>
+#include <MailImporter/FilterClawsMail>
+#include <MailImporter/FilterEvolution>
+#include <MailImporter/FilterEvolution_v2>
+#include <MailImporter/FilterEvolution_v3>
+#include <MailImporter/FilterIcedove>
+#include <MailImporter/FilterOpera>
+#include <MailImporter/FilterSylpheed>
+#include <MailImporter/FilterThunderbird>
+#include <MailImporter/OtherMailerUtil>
 
 #include <MessageCore/StringUtil>
 
 #include <MessageComposer/MessageHelper>
 
-#include <AgentManager>
-#include <entitymimetypefiltermodel.h>
-#include <EntityTreeModel>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
+#include <Akonadi/AgentManager>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <Akonadi/KMime/MessageParts>
-#include <AkonadiCore/NewMailNotifierAttribute>
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/KMime/NewMailNotifierAttribute>
+#include <Akonadi/ServerManager>
 
 #include <KMime/KMimeMessage>
 
 #include <KColorScheme>
-#include <KJob>
 #include <KIO/JobUiDelegate>
+#include <KJob>
 #include <collectionpage/attributes/expirecollectionattribute.h>
 
-OrgKdeAkonadiPOP3SettingsInterface *MailCommon::Util::createPop3SettingsInterface(
-    const QString &ident)
+OrgKdeAkonadiPOP3SettingsInterface *MailCommon::Util::createPop3SettingsInterface(const QString &ident)
 {
     const auto service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, ident);
     return new OrgKdeAkonadiPOP3SettingsInterface(service, QStringLiteral("/Settings"), QDBusConnection::sessionBus());
@@ -110,8 +77,7 @@ QString MailCommon::Util::fullCollectionPath(const Akonadi::Collection &collecti
 {
     QString fullPath;
 
-    QModelIndex idx
-        = Akonadi::EntityTreeModel::modelIndexForCollection(KernelIf->collectionModel(), collection);
+    QModelIndex idx = Akonadi::EntityTreeModel::modelIndexForCollection(KernelIf->collectionModel(), collection);
     if (!idx.isValid()) {
         return fullPath;
     }
@@ -152,8 +118,7 @@ Akonadi::AgentInstance::List MailCommon::Util::agentInstances(bool excludeMailDi
 {
     Akonadi::AgentInstance::List relevantInstances;
     const Akonadi::AgentInstance::List agentList = Akonadi::AgentManager::self()->instances();
-    std::copy_if(agentList.cbegin(), agentList.cend(), std::back_inserter(relevantInstances),
-                 [excludeMailDispacher](const Akonadi::AgentInstance &instance) {
+    std::copy_if(agentList.cbegin(), agentList.cend(), std::back_inserter(relevantInstances), [excludeMailDispacher](const Akonadi::AgentInstance &instance) {
         return isMailAgent(instance, excludeMailDispacher);
     });
     return relevantInstances;
@@ -166,10 +131,8 @@ bool MailCommon::Util::isMailAgent(const Akonadi::AgentInstance &instance, bool
     }
 
     const QStringList capabilities(instance.type().capabilities());
-    if (capabilities.contains(QLatin1String("Resource"))
-        && !capabilities.contains(QLatin1String("Virtual"))
-        && !capabilities.contains(QLatin1String("MailTransport"))
-        && !capabilities.contains(QLatin1String("Autostart"))) {
+    if (capabilities.contains(QLatin1String("Resource")) && !capabilities.contains(QLatin1String("Virtual"))
+        && !capabilities.contains(QLatin1String("MailTransport")) && !capabilities.contains(QLatin1String("Autostart"))) {
         return true;
     } else if (!excludeMailTransport && instance.identifier() == QLatin1String("akonadi_maildispatcher_agent")) {
         return true;
@@ -191,8 +154,7 @@ uint MailCommon::Util::folderIdentity(const Akonadi::Item &item)
         if (col.resource().isEmpty()) {
             col = CommonKernel->collectionFromId(col.id());
         }
-        const QSharedPointer<FolderSettings> fd
-            = FolderSettings::forCollection(col, false);
+        const QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(col, false);
 
         id = fd->identity();
     }
@@ -215,14 +177,14 @@ QString MailCommon::Util::realFolderPath(const QString &path)
     realPath.remove(QStringLiteral(".directory"));
     realPath.replace(QLatin1String("/."), QStringLiteral("/"));
     if (!realPath.isEmpty() && (realPath.at(0) == QLatin1Char('.'))) {
-        realPath.remove(0, 1);   //remove first "."
+        realPath.remove(0, 1); // remove first "."
     }
     return realPath;
 }
 
 void MailCommon::Util::expireOldMessages(const Akonadi::Collection &collection, bool immediate)
 {
-    ScheduledExpireTask *task = new ScheduledExpireTask(collection, immediate);
+    auto task = new ScheduledExpireTask(collection, immediate);
     KernelIf->jobScheduler()->registerTask(task);
 }
 
