@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "favoritecollectionwidget.h"
@@ -23,23 +11,23 @@
 
 #include <MessageCore/MessageCoreSettings>
 
+#include <Akonadi/CollectionStatisticsDelegate>
+#include <KActionCollection>
+#include <KActionMenu>
 #include <KLocalizedString>
 #include <KXMLGUIClient>
-#include <KActionMenu>
-#include <KActionCollection>
-#include <AkonadiWidgets/CollectionStatisticsDelegate>
 
-#include <QPainter>
 #include <QFontDatabase>
-#include <QMouseEvent>
 #include <QMimeData>
+#include <QMouseEvent>
+#include <QPainter>
 
 using namespace MailCommon;
 
-class Q_DECL_HIDDEN FavoriteCollectionWidget::Private
+class Q_DECL_HIDDEN FavoriteCollectionWidget::FavoriteCollectionWidgetPrivate
 {
 public:
-    Private()
+    FavoriteCollectionWidgetPrivate()
     {
     }
 
@@ -51,12 +39,12 @@ public:
 
 FavoriteCollectionWidget::FavoriteCollectionWidget(MailCommon::MailCommonSettings *settings, KXMLGUIClient *xmlGuiClient, QWidget *parent)
     : Akonadi::EntityListView(xmlGuiClient, parent)
-    , d(new Private)
+    , d(new FavoriteCollectionWidgetPrivate)
 {
     d->settings = settings;
     setFocusPolicy(Qt::NoFocus);
 
-    Akonadi::CollectionStatisticsDelegate *delegate = new Akonadi::CollectionStatisticsDelegate(this);
+    auto delegate = new Akonadi::CollectionStatisticsDelegate(this);
     delegate->setProgressAnimationEnabled(true);
 
     setItemDelegate(delegate);
@@ -68,10 +56,7 @@ FavoriteCollectionWidget::FavoriteCollectionWidget(MailCommon::MailCommonSetting
     createMenu(xmlGuiClient->actionCollection());
 }
 
-FavoriteCollectionWidget::~FavoriteCollectionWidget()
-{
-    delete d;
-}
+FavoriteCollectionWidget::~FavoriteCollectionWidget() = default;
 
 void FavoriteCollectionWidget::mousePressEvent(QMouseEvent *e)
 {
@@ -96,14 +81,14 @@ void FavoriteCollectionWidget::updateMode()
 
 void FavoriteCollectionWidget::createMenu(KActionCollection *ac)
 {
-    KActionMenu *iconSizeMenu = new KActionMenu(i18n("Icon size"), this);
+    auto iconSizeMenu = new KActionMenu(i18n("Icon size"), this);
     ac->addAction(QStringLiteral("favorite_icon_size"), iconSizeMenu);
 
-    static const int icon_sizes[] = { 16, 22, 32 /*, 48, 64, 128 */ };
+    static const int icon_sizes[] = {16, 22, 32 /*, 48, 64, 128 */};
 
-    QActionGroup *grp = new QActionGroup(iconSizeMenu);
+    auto grp = new QActionGroup(iconSizeMenu);
     QAction *act = nullptr;
-    for (int i  : icon_sizes) {
+    for (int i : icon_sizes) {
         act = new QAction(QStringLiteral("%1x%2").arg(i).arg(i), iconSizeMenu);
         iconSizeMenu->addAction(act);
         act->setCheckable(true);
@@ -115,7 +100,7 @@ void FavoriteCollectionWidget::createMenu(KActionCollection *ac)
         connect(act, &QAction::triggered, this, &FavoriteCollectionWidget::slotChangeIconSize);
     }
 
-    KActionMenu *modeFavoriteMenu = new KActionMenu(i18n("Mode"), this);
+    auto modeFavoriteMenu = new KActionMenu(i18n("Mode"), this);
     ac->addAction(QStringLiteral("favorite_mode"), modeFavoriteMenu);
 
     grp = new QActionGroup(modeFavoriteMenu);
@@ -142,7 +127,7 @@ void FavoriteCollectionWidget::createMenu(KActionCollection *ac)
 
 void FavoriteCollectionWidget::slotChangeMode(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto act = qobject_cast<QAction *>(sender());
     if (!act) {
         return;
     }
@@ -177,7 +162,7 @@ void FavoriteCollectionWidget::changeViewMode(QListView::ViewMode mode)
 
 void FavoriteCollectionWidget::slotChangeIconSize(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto act = qobject_cast<QAction *>(sender());
     if (!act) {
         return;
     }
